@@ -1,13 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- * author Greg Hill <greg.hill@open-xchange.com>
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/auth', [
@@ -25,50 +35,25 @@ define('oxguard/auth', [
     auth_core.authorize = function authorize(baton, o) {
         var options = _.extend({}, o);
         var def = $.Deferred();
-        if (isFile(baton) && core.hasLocalKeys()) {  // If file and local, we need to pull the session keys, etc
-            require(['pgp_local/localHandler'], function (local) {
-                local.fileFound(baton, options.optPrompt, options.minSingleUse)
-                .done(function (auth) {
-                    def.resolve(auth);
-                    if (_.isFunction(options.callback)) {
-                        options.callback(auth);
-                    }
-                })
-                .fail(function () {
-                    checkAuth(options, def);
-                    if (_.isFunction(options.failAuthCheck)) {
-                        options.failAuthCheck();
-                    }
-                });
-            });
-        } else {
-            checkAuth(options, def);
-        }
+        checkAuth(options, def);
         return def;
     };
 
-    function isFile(baton) {
-        var file;
-        if (_.isArray(baton)) {
-            file = {
-                data: baton[0]
-            };
-        } else {
-            file = baton;
-        }
-        if (file && file.data) {
-            if (file.data.filename || file.data.source === 'drive' || file.data.source === 'guardDrive') return true;
-        }
-        return false;
-    }
-
+    // Authentication for PGP items
     function doAuthCheck(options, def) {
         if (options.forceRelogin) {  // If we must relogin, show password prompt
             promptPassword(options, def);
         } else { // Else check if we have authentication already in session
             core.checkAuth(options)
             .done(function (data) {
-                def.resolve(data.auth);
+                var found = false;
+                data.forEach(function (d) {
+                    if (!options.type || d.type.toLowerCase() === options.type.toLowerCase()) {
+                        def.resolve(d.auth);
+                        found = true;
+                    }
+                });
+                if (!found) promptPassword(options, def);
             })
             .fail(function () {
                 promptPassword(options, def);
@@ -86,13 +71,25 @@ define('oxguard/auth', [
         }, def.reject);
     }
 
+    function getPrompt(o) {
+        if (o.optPrompt) return o.optPrompt;
+        if (o && o.type) {
+            if (core.hasPGPandSmime()) {
+                if (o.type.toLowerCase() === 'smime') {
+                    return gt('Enter %s S/MIME security password', ox.guard.getName());
+                }
+                return gt('Enter %s PGP security password', ox.guard.getName());
+            }
+        }
+    }
+
     // Display password prompt to authorize
     function promptPassword(options, def) {
-        var prompt = options.optPrompt ? options.optPrompt : gt('Enter %s security password', window.oxguarddata.productName);
+        var prompt = getPrompt(options);
         core.getPassword(prompt, true, options)  //Get password
         .done(function (passdata) {
             if (passdata.duration > -1 || options.minSingleUse) {
-                core.savePassword(passdata.password, passdata.duration)
+                core.savePassword(passdata.password, passdata.duration, options.type)
                 .done(function (data) {
                     def.resolve(data.auth);
                     if (_.isFunction(options.callback)) {
@@ -107,7 +104,7 @@ define('oxguard/auth', [
                     def.reject(data.auth, data);
                 });
             } else {
-                core.auth(ox.user_id, passdata.password)
+                core.auth(ox.user_id, passdata.password, options.type)
                 .done(function (data) {
                     if (data.auth.length > 20 && !(/Error:/i.test(data.auth))) {
                         if (_.isFunction(options.callback)) {
@@ -130,11 +127,11 @@ define('oxguard/auth', [
     }
 
     function ensureLoaded() {
-        if (window.oxguarddata.loaded) return $.when();
+        if (ox.guard.isLoaded()) return $.when();
         var def = $.Deferred();
         var counter = 0;
         var timer = setInterval(function () {
-            if (window.oxguarddata.loaded) {
+            if (ox.guard.isLoaded()) {
                 def.resolve();
                 clearInterval(timer);
             }
@@ -159,9 +156,8 @@ define('oxguard/auth', [
                 });
                 return;
             }
-
             // If keys were set up by receiving email, possible user hasn't had prompt to create password.
-            if (window.oxguarddata.passcode === 'Password Needed') {
+            if (ox.guard.needsPassword()) {
                 require(['oxguard/core/tempPassword'], function (tempPass) {
                     var go = function () {
                         def.resolve();
