@@ -1,129 +1,109 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/core/createKeys', [
-    'oxguard/core/og_http',
-    'io.ox/core/extensions',
-    'oxguard/oxguard_core',
     'io.ox/backbone/views/modal',
     'oxguard/core/passwordView',
+    'oxguard/api/keys',
     'gettext!oxguard',
     'less!oxguard/core/style'
-], function (og_http, ext, core, ModalView, PasswordView, gt) {
+], function (ModalDialog, PasswordView, keysAPI, gt) {
 
     'use strict';
 
-    var CreateKeysViewModel = Backbone.Model.extend({
-        initialize: function () {
-            //FIXME: reduce callback hell a little
-            if (window.oxguarddata.username === undefined) {
-                require(['io.ox/core/api/user']).done(function (user) {
-                    window.oxguarddata.username = user.getName().done(function (data) {
-                        window.oxguarddata.username = data;
-                    });
+    /**
+     * @returns deferred object resolves to one of:
+     *  * "OK" - everything is fine
+     *  * "cancel" - user cancelled the dialog
+     *  * object - failed with error message stored in responseText attribute
+     */
+    // Prompt for creating master keys for this user if not yet created.
+    function openDialog() {
+        var def = $.Deferred();
+
+        new ModalDialog({
+            async: true,
+            point: 'oxguard/core/createKeys',
+            title: gt('Create %s Security Keys', ox.guard.getName()),
+            width: 640,
+            enter: 'ok',
+            focus: '#newogpassword'
+        })
+        .extend({
+            'view': function () {
+                this.view = new View({
+                    model: new Model()
                 });
-            }
-        },
-        defaults: {
-            email: '',
-            initialSetup: false,
-            sent: false
-        },
-        toJSON: function () {
-            var userdata = {};
-
-            if (window.oxguarddata.username !== undefined) userdata.name = window.oxguarddata.username;
-
-            return _.extend(userdata, this.pick('email', 'password'));
-        },
-        send: function () {
-            var self = this;
-            this.trigger('before:send');
-            if (!this.isValid()) {
-                this.trigger('send send:error', this.validationError);
-                return;
-            }
-            og_http.simplePost(ox.apiRoot + '/oxguard/keys?action=create', (this.get('initialSetup') ? '' : '&add=true'), this.toJSON())
-            .done(function (data) {
-                if (core.checkJsonOK(data)) {
-                    window.oxguarddata.passcode = null;
-                    window.oxguarddata.recoveryAvail = window.oxguarddata.recovery = !window.oxguarddata.settings.noRecovery;
-                    self.trigger('send send:ok');
-                    self.set('sent', true);
-                    if (window.oxguarddata.recovery) window.oxguarddata.recoveryAvail = true;
-                } else {
-                    self.trigger('send send:error', gt('Problems creating keys, please try again later.'));
-                }
-            })
-            .fail(function (data) {
-                var error;
-                if (data.responseText.trim() === 'Existing') {
-                    error = gt('Problems creating keys. Keys already exist for this email address in another account.');
-                } else {
-                    error = gt('Problems creating keys, please try again later.');
-                }
-                self.trigger('send send:error', error);
-            });
-        },
-        validate: function (attrs) {
-            var errors = [];
-            var minlen = window.oxguarddata.settings.min_password_length;
-            if (minlen !== undefined && attrs.password !== undefined && attrs.password.length < minlen) {
-                errors.push({
-                    field: '.password',
-                    message: gt('Passwords must be at least %s characters in length', minlen)
+                this.$body.append(
+                    this.view.render().$el
+                );
+            },
+            'button-state': function () {
+                var button = this.$('button[data-action=ok]');
+                // initial value
+                button.attr({
+                    // disable automatic state management of modal dialog
+                    'data-state': 'manual',
+                    'disabled': true
                 });
-            }
-            if (attrs.password !== attrs.passwordValidation) {
-                errors.push({
-                    field: '.password-validation',
-                    message: gt('Passwords not equal')
+                this.view.listenTo(this.view.model, 'change', function (model) {
+                    button.attr('disabled', !model.isValid());
                 });
+            },
+            'deferred': function () {
+                this.view.listenTo(this.view.model, 'send', function (error) {
+                    this.close();
+                    return error ?
+                        def.reject({ responseText: error }) :
+                        def.resolve('OK');
+                }.bind(this));
             }
-            if ((attrs.email.length > 1) && (!validateEmail(attrs.email))) {
-                errors.push({
-                    field: '.email',
-                    message: gt('Enter new secondary Email address')
-                });
-            }
-            return errors.length === 0 ? undefined : errors;
-        },
-        //handle password strength warnings (those not catched by validate) - adopted from oxquard/core/passwords.passwordCheck
-        checkStrength: function () {
-            var min = window.oxguarddata.settings.min_password_length;
-            var len = window.oxguarddata.settings.password_length;
-            if (min === undefined) min = 6;
-            if (len === undefined) len = 10;
+        })
+        .addButton({ label: gt('OK'), action: 'ok' })
+        .addCancelButton()
+        .on('cancel', function () {
+            def.reject('cancel');
+        })
+        .on('ok', function () {
+            this.view.model.send();
+        })
+        .on('dispose', function () {
+            this.view.remove();
+            this.view = null;
+        })
+        .open();
 
-            if (len <= min) len = min + 1;
-            if (!this.get('password')) return;
+        return def;
+    }
 
-            if (this.get('password').length < min) {
-                this.set('passwordStrength', 'bad');
-                return;
-            }
+    function validateEmail(email) {
+        var re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
+        return re.test(email);
+    }
 
-            var regex = /(?=^.{8,}$)(?=.*\d)(?=.*[!@#$%^&*]+)(?![.\n])(?=.*[A-Z])(?=.*[a-z]).*$/;
-            if (this.get('password').match(regex)) {
-                this.set('passwordStrength', 'good');
-                return;
-            }
+    var View = Backbone.View.extend({
 
-            this.set('passwordStrength', 'weak');
-        }
-    });
-
-    var CreateKeysView = Backbone.View.extend({
         className: 'guard-create-key form-horizontal',
         initialize: function () {
-            if (!this.model) this.model = new CreateKeysViewModel();
             this.listenTo(this.model, 'change', this.handleChange);
             this.listenTo(this.model, 'before:send', this.busy);
             this.listenTo(this.model, 'send', this.idle);
@@ -183,10 +163,23 @@ define('oxguard/core/createKeys', [
         idle: function () {
             this.$wait.hide();
         },
-
+        render: function () {
+            this.$el.empty().append(this.$wait);
+            return this
+                .renderDescription(this.$el)
+                .renderPasswordPrompt(this.$el)
+                .renderRecoverMailPrompt(this.$el);
+        },
         renderDescription: function (el) {
+            var prompt = '';
+            if (this.model.get('initialSetup')) {
+                prompt = gt('Please choose the password you will use for %s. You will need to type this password whenever you want to encrypt or decrypt items. Remember it should be different from your login password, and will not change if you change your login password.', ox.guard.getName());
+            }
+            if (this.model.get('prompt')) {
+                prompt = this.model.get('prompt');
+            }
             el.append($('<div>').append(
-                this.model.get('initialSetup') ? $('<p>').text(gt('Please choose the password you will use for %s. You will need to type this password whenever you want to encrypt or decrypt items. Remember it should be different from your login password, and will not change if you change your login password.', window.oxguarddata.productName)) : '',
+                $('<p>').text(prompt),
                 $('<p>').text(gt('Please enter a password to protect your new encrypted items.'))
             ));
             return this;
@@ -222,7 +215,7 @@ define('oxguard/core/createKeys', [
             return this;
         },
         renderRecoverMailPrompt: function (el) {
-            if (window.oxguarddata.settings.noRecovery === true) {
+            if (ox.guard.getSettings().noRecovery === true) {
                 el.append($('<hr style="padding:10px;"/>'),
                     $('<p class="oxguard_warning">').text(gt('Warning: This password for encryption cannot be restored or recovered in any way.  If forgotten, all encrypted data will be lost')));
                 return this;  // If no recovery set, don't add prompt for second password
@@ -241,110 +234,114 @@ define('oxguard/core/createKeys', [
                 );
             }
             return this;
+        }
+
+    });
+
+    var Model = Backbone.Model.extend({
+        initialize: function () {
+            var self = this;
+            if (ox.guard.get('username')) return;
+            // FIXME: should be handled differently (potential race conditions)
+            require(['io.ox/core/api/user'], function (userAPI) {
+                userAPI.getName().then(function (name) {
+                    ox.guard.set('username', name);
+                    self.set('name', name, { silent: true });
+                });
+            });
+
         },
-        render: function () {
-            this.$el.empty().append(this.$wait);
-            return this
-                .renderDescription(this.$el)
-                .renderPasswordPrompt(this.$el)
-                .renderRecoverMailPrompt(this.$el);
+        defaults: {
+            name: ox.guard.get('username') || '',
+            password: '',
+            email: '',
+            // config
+            initialSetup: false,
+            sent: false
+        },
+        send: function () {
+            var self = this;
+            this.trigger('before:send');
+            if (!this.isValid()) {
+                this.trigger('send send:error', this.validationError);
+                return;
+            }
+            return keysAPI.create(this.pick('name', 'password', 'email')).then(function (data) {
+                // TODO: maybe move to keysAPI
+                ox.guard.clearAuth();
+                ox.guard.set('recoveryAvail', !ox.guard.getSettings().noRecovery);
+                this.set('sent', true);
+                self.trigger('send send:ok');
+                return data;
+            }.bind(this), function (data) {
+                // TODO: indicator for error that key already exists
+                // gt('Problems creating keys. Keys already exist for this email address in another account.')
+                self.trigger('send send:error', gt('Problems creating keys, please try again later.'));
+                return data;
+            });
+        },
+        validate: function (attrs) {
+            var errors = [];
+            var minlen = ox.guard.getSettings().min_password_length;
+            if (minlen !== undefined && attrs.password !== undefined && attrs.password.length < minlen) {
+                errors.push({
+                    field: '.password',
+                    message: gt('Passwords must be at least %s characters in length', minlen)
+                });
+            }
+            if (attrs.password !== attrs.passwordValidation) {
+                errors.push({
+                    field: '.password-validation',
+                    message: gt('Passwords not equal')
+                });
+            }
+            if ((attrs.email.length > 1) && (!validateEmail(attrs.email))) {
+                errors.push({
+                    field: '.email',
+                    message: gt('Enter new secondary Email address')
+                });
+            }
+            return errors.length === 0 ? undefined : errors;
+        },
+        //handle password strength warnings (those not catched by validate) - adopted from oxquard/core/passwords.passwordCheck
+        checkStrength: function () {
+            var min = ox.guard.getSettings().min_password_length;
+            var len = ox.guard.getSettings().password_length;
+            if (min === undefined) min = 6;
+            if (len === undefined) len = 10;
+
+            if (len <= min) len = min + 1;
+            if (!this.get('password')) return;
+
+            if (this.get('password').length < min) {
+                this.set('passwordStrength', 'bad');
+                return;
+            }
+
+            var regex = /(?=^.{8,}$)(?=.*\d)(?=.*[!@#$%^&*]+)(?![.\n])(?=.*[A-Z])(?=.*[a-z]).*$/;
+            if (this.get('password').match(regex)) {
+                this.set('passwordStrength', 'good');
+                return;
+            }
+
+            this.set('passwordStrength', 'weak');
         }
     });
 
+
     function createKeysWizard() {
         var def = $.Deferred();
         require(['io.ox/core/tk/wizard', 'oxguard/tour/main'], function (Tour) {
             Tour.registry.get('default/oxguard/createKeys').get('run')().then(def.resolve, def.reject);
-
         });
         return def;
     }
 
-    var POINT = 'oxguard/core/createKeys';
-
-    ext.point(POINT).extend({
-        index: 100,
-        id: 'header',
-        render: function (baton) {
-            var view = baton.model.get('view');
-            this.$body.append(
-                view.render().$el
-            );
-        }
-    });
-
-    /**
-     * @returns deferred object resolves to one of:
-     *  * "OK" - everything is fine
-     *  * "cancel" - user cancelled the dialog
-     *  * object - failed with error message stored in responseText attribute
-     */
-    // Prompt for creating master keys for this user if not yet created.
-    function createKeys() {
-        var def = $.Deferred(),
-            view = new CreateKeysView();
-
-        var dialog = new ModalView({
-            async: true,
-            point: POINT,
-            title: gt('Create %s Security Keys', window.oxguarddata.productName),
-            width: 640,
-            enter: 'ok',
-            focus: '#newogpassword',
-            model: new Backbone.Model({ 'view': view })
-        })
-        .build(function () {
-        })
-        .addButton({ label: gt('OK'), action: 'ok' })
-        .addCancelButton()
-        .on('cancel', function () {
-            def.reject('cancel');
-        })
-        .on('ok', function () {
-            view.model.once('send', function (error) {
-                dialog.close();
-                if (error) {
-                    def.reject({
-                        responseText: error
-                    });
-                    return;
-                }
-                def.resolve('OK');
-            });
-            view.model.send();
-        })
-        .on('open', function () {
-            var el = this.$footer.find('button[data-action=ok]');
-            el.attr('disabled', true);
-        })
-        .open();
-        view.model.on('change', function (model) {
-            var el = dialog.$footer.find('button[data-action=ok]');
-            if (model.isValid()) {
-                el.removeAttr('disabled');
-            } else {
-                el.attr('disabled', true);
-            }
-        });
-        def.always(function () {
-            view.remove();
-            view.model.off();
-            view.model = null;
-            view = null;
-        });
-        return def;
-    }
-
-    function validateEmail(email) {
-        var re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
-        return re.test(email);
-    }
-
     return {
-        createKeys: createKeys,
+        createKeys: openDialog,
         createKeysWizard: createKeysWizard,
-        CreateKeysViewModel: CreateKeysViewModel,
-        CreateKeysView: CreateKeysView
+        CreateKeysModel: Model,
+        CreateKeysView: View
     };
 
 });
