@@ -1,12 +1,25 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/core/og_http', [], function () {
 
     'use strict';
@@ -86,7 +99,7 @@ define('oxguard/core/og_http', [], function () {
     function postAction(url, params, data, json) {
         var def = $.Deferred();
         require(['oxguard/crypto/encr'], function (encr) {
-            if (window.oxguarddata && window.oxguarddata.pubKey !== undefined && data !== undefined) {
+            if (ox.guard.get('pubKey') !== undefined && data !== undefined) {
                 if (data.password !== undefined) {
                     if (data.password !== '') {
                         var epass = encr.cryptPass(data.password);
@@ -114,7 +127,7 @@ define('oxguard/core/og_http', [], function () {
                         }
                     }
                 }
-                data.keyIndex = window.oxguarddata.pubKey.index;
+                data.keyIndex = ox.guard.get('pubKey').index;
             }
             doPost(url, params, data, json)
             .done(function (e) {
