@@ -1,11 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/files/register', [
@@ -330,11 +342,30 @@ define('oxguard/files/register', [
         action: function (baton) {
             ensureSetup().then(function () {
                 baton.file_options = { 'params': { 'cryptoAction': 'Encrypt' } };
+                baton.guardFileOnce = true;
                 actionsUtil.invoke('io.ox/files/actions/upload', baton);
             });
         }
     });
 
+    // Make sure that the cryptoAction flag is only passed once to the upload, unless user intentionally selects upload encrypted twice
+    // Bug Guard-269
+    ext.point('io.ox/files/actions/upload').replace('default', function (original) {
+        return {
+            action: function (baton) {
+                // If via the uploadEncrypt action, perform with the cryptoActions
+                if (baton.guardFileOnce) {
+                    baton.guardFileOnce = false;
+                    original.action(baton);
+                    return;
+                }
+                // Wipe the cryptoActions
+                baton.file_options = { params: { cryptoAction: '' } };
+                original.action(baton);
+            }
+        };
+    });
+
     new actionsUtil.Action('oxguard/downloadEncrypted', {
         matches: function (baton) {
             if (baton.first()) {
@@ -379,7 +410,7 @@ define('oxguard/files/register', [
                 if (isOGFile(baton.first())) {
                     require(['oxguard/auth'], function (auth_core) {
                         var options = {
-                            optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+                            optPrompt: gt('Please re-enter your %s password.', ox.guard.getName()),
                             minSingleUse: true
                         };
                         auth_core.authorize(baton, options)
@@ -514,19 +545,15 @@ define('oxguard/files/register', [
 
     function doRemEncryptFile(list) {
         require(['io.ox/files/api'], function (fileApi) {
-            fileApi.copy(list, list[0].folder_id, false)
-            .then(function (e) {
-                if (e.length === list.length) {
-                    for (var i in list) {
-                        if (e[i].data) {
-                            fileApi.remove([list[i]], true);
-                        }
-                    }
-                } else if (_.isString(e)) {
-                    require(['io.ox/core/notifications'], function (notify) {
-                        notify.yell('error', e);
-                    });
-                }
+            list.forEach(function (f) {
+                fileApi.copy([f], f.folder_id, false)
+                      .then(function (e) {
+                          if (e.length === 1) {
+                              fileApi.remove([f], true);
+                          } else if (_.isString(e)) {
+                              oxguard.notifyError(e);
+                          }
+                      });
             });
         });
     }
@@ -795,19 +822,15 @@ define('oxguard/files/register', [
 
     function doEncryptFile(list) {
         require(['io.ox/files/api'], function (fileApi) {
-            fileApi.copy(list, list[0].folder_id, false)
-            .then(function (e) {
-                if (e.length === list.length) {
-                    for (var i in list) {
-                        if (e[i].data) {
-                            fileApi.remove([list[i]], true);
-                        }
-                    }
-                } else if (_.isString(e)) {
-                    require(['io.ox/core/notifications'], function (notify) {
-                        notify.yell('error', e);
-                    });
-                }
+            list.forEach(function (f) {
+                fileApi.copy([f], f.folder_id, false)
+                  .then(function (e) {
+                      if (e.length === 1) {
+                          fileApi.remove([f], true);
+                      } else if (_.isString(e)) {
+                          oxguard.notifyError(e);
+                      }
+                  });
             });
         });
     }
