@@ -1,11 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/guestPrompt', [
@@ -21,7 +33,7 @@ define('oxguard/mail/guestPrompt', [
     function guestOptions(baton) {
 
         var def = $.Deferred();
-        var dialog = new dialogs.CreateDialog({ width: 490, center: true, enter: 'ok' });
+        var dialog = new dialogs.CreateDialog({ width: 490, center: true, enter: 'ok', addClass: 'onTop' });
         dialog.header($('<h4>').text(gt('Recipient Options')));
         var help = $('<p>' + gt('At least one of your recipients uses a different webmail system.  They will receive an email with a link for them to read this message.  If you like, you can add a personalized message that will appear at the top of this message.  This will help identify the message as coming from you.') + '</p>');
         var messageLabel = $('<label class="oxguard_message_label">' + gt('Message:') + '</label>');
@@ -30,7 +42,7 @@ define('oxguard/mail/guestPrompt', [
         var langselect = $('<select class="og_language"></select>');
         var warning = $('<p class="oxguard_warn" style="margin-top:10px;">').append(gt('Note: Emails sent to mailing lists or groups will not work.'));
         // Populate language selector with languages avail
-        var languages = window.oxguarddata.lang;
+        var languages = ox.guard.get('lang');
         $.each(languages, function (c, n) {
             langselect.append('<option value="' + c + '">' + n + '</option>');
         });
