@@ -1,30 +1,46 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/keymanager', [
-    'oxguard/core/og_http',
-    'gettext!oxguard',
+    'oxguard/api/keys',
+    'oxguard/api/certs',
     'oxguard/oxguard_core',
-    'settings!io.ox/calendar'
-], function (og_http, gt, core, calSettings) {
+    'settings!io.ox/calendar',
+    'gettext!oxguard'
+], function (keysAPI, certsAPI, core, calSettings, gt) {
 
     'use strict';
 
-    var blackList;   // We only want to pull the blacklist once
+    // We only want to pull the blacklist once
+    var blackList;
 
     // Check the list of previously fetched key results to see if the email is there.  If so, return, otherwise query backend
     function checkRecips(email, baton) {
-        var def = $.Deferred();
-        var gkeys = baton.config.get('gkeys');
-        if (gkeys === undefined) { // If undefined, create gkeys now
-            gkeys = [];
+        var def = $.Deferred(),
+            gkeys = baton.config.get('gkeys');
+
+        if (gkeys === undefined) {
+            // If undefined, create gkeys now
+            gkeys = {};
             baton.config.set('gkeys', gkeys);
             getKeyResult(email, baton)
             .done(function (keyResults) {
@@ -48,40 +64,44 @@ define('oxguard/mail/keymanager', [
 
     // Query guard server for key result
     function getKeyResult(email, baton) {
-        var def = $.Deferred();
-        var result = {
-            email: email,
-            result: null,
-            pending: true,
-            def: def
-        };
-        var gkeys = baton.config.get('gkeys');
+        var def = $.Deferred(),
+            result = {
+                email: email,
+                result: null,
+                pending: true,
+                def: def
+            },
+            gkeys = baton.config.get('gkeys');
+
         gkeys[email] = result;
         baton.config.set('gkeys', gkeys);
+        var smime = baton.view.securityModel.get('smime');
         if (isBlackListed(email)) {
             require(['io.ox/core/notifications'], function (notifications) {
                 notifications.yell('error', gt('Mailing list / blocked email found.  Encrypted emails to this email will fail.  %s', email));
             });
             baton.view.securityModel.set('encrypt', false);
-            def.resolve(updateKeys(email, baton, 'fail'));
-            return def;
+            def.resolve(updateKeys(email, baton, 'fail', undefined, smime));
         }
-        var params = '&email=' + encodeURIComponent(email);
-        og_http.get(ox.apiRoot + '/oxguard/keys?action=getRecipKey', params)
-        .done(function (result) { //Get the key
+
+        return (smime ? certsAPI : keysAPI).getRecipientsPublicKey(email).then(function (data) {
             try {
-                var data;
-                if ($.isArray(result)) {  // error responses sent as array
-                    data = result[0];
-                } else {
-                    data = result.data;
+                var encryptionKey;
+                if (!data) {  // No key data
+                    return { result: 'fail', keyData: undefined };
                 }
-                if (core.checkJsonOK(result)) {
+                if (data.preferredFormat === 'PGP/INLINE') {
+                    // If needs inline, then set
+                    baton.view.securityModel.setInline();
+                }
+                if (core.checkJsonOK(data)) {
+                    if (smime) {
+                        return { result: 'smime', keyData: data };
+                    }
                     if (data.preferredFormat === 'PGP/INLINE') { // If needs inline, then set
                         baton.view.securityModel.setInline();
                     }
                     var keys = (data.publicRing && data.publicRing.keys) ? data.publicRing.keys : undefined;
-                    var encryptionKey;
                     if (keys) {
                         keys.forEach(function (key) {
                             if (key.encryptionKey && !key.expired && !key.revoked) {
@@ -92,36 +112,24 @@ define('oxguard/mail/keymanager', [
                             }
                         });
                     }
-                    if (encryptionKey || data.newKey) {
-                        // Expired keys.  Should never occur.  Remove code?
-                        if (encryptionKey && encryptionKey.expired === true) {
-                            def.resolve(updateKeys(email, baton, 'fail', encryptionKey));
-                            require(['io.ox/core/notifications'], function (notifications) {
-                                notifications.yell('error', gt('The key for %s has expired.  You will not be able to send an encrypted email to this recipient.', data.email));
-                            });
-                            return def;
-                        }
-                        //
-                        if (data.guest && data.newKey) {
-                            def.resolve(updateKeys(email, baton, 'guest', encryptionKey));
-                        } else {
-                            def.resolve(updateKeys(email, baton, (data.newKey ? 'new' : 'pgp'), encryptionKey));
-                        }
-                    } else {
-                        def.resolve(updateKeys(email, baton, 'fail', encryptionKey));
+                    //
+                    if (data.guest && data.newKey) {
+                        return { result: 'guest', keyData: encryptionKey };
                     }
-                } else {
-                    def.resolve(updateKeys(email, baton, 'fail', data));
+                    return { result: data.newKey ? 'new' : 'pgp', keyData: encryptionKey };
+
                 }
 
+                return { result: 'fail', keyData: encryptionKey };
+
             } catch (e) {
                 console.log(e);
             }
-        })
-        .fail(function () {
-            def.resolve(updateKeys(email, baton, 'fail'));
+        }, function (error) {
+            return { result: 'fail', keyData: error };
+        }).then(function (data) {
+            return def.resolve(updateKeys(email, baton, data.result, data.keyData, smime));
         });
-        return def;
     }
 
     // Check if email is in blacklist
@@ -144,15 +152,19 @@ define('oxguard/mail/keymanager', [
     }
 
     // Update the list of gkeys with the result
-    function updateKeys(email, baton, result, keyData) {
+    function updateKeys(email, baton, result, keyData, smime) {
         var gkeys = baton.config.get('gkeys');
-        gkeys[email] = {
-            result: result,
-            pending: false,
-            key: keyData
-        };
-        baton.config.set('gkeys', gkeys);
-        baton.model.trigger('change:gkeys');
+        if ((smime === true) === baton.view.securityModel.get('smime')) {
+            gkeys[email] = {
+                result: result,
+                pending: false,
+                key: keyData
+            };
+
+            baton.config.set('gkeys', gkeys);
+            baton.model.trigger('change:gkeys');
+        }
+
         return gkeys;
     }
 
@@ -171,6 +183,7 @@ define('oxguard/mail/keymanager', [
         var gkeys = baton.config.get('gkeys');
         delete gkeys[email];
         baton.config.set('gkeys', gkeys);
+        baton.model.trigger('change:gkeys');
     }
 
     // Check if an email is located in gkeys
