@@ -1,11 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/options_new', [
@@ -37,10 +49,13 @@ define('oxguard/mail/options_new', [
     }
 
     function warnHTML(baton) {
-        var format = baton.view.securityModel.get('PGPFormat');
+        if (baton.view.securityModel.get('smime')) return;  // Doesn't apply to smime
+        var inline = baton.view.securityModel.get('pgpInline');
         var encrypt = baton.view.securityModel.get('encrypt');
-        if (format !== 'inline' || !encrypt) return;  // Don't display warning if not Inline or not encrypted
+        if (!inline || !encrypt) return;  // Don't display warning if not Inline or not encrypted
         if (baton.config.get('editorMode') === 'text') return;
+        if (baton.view.securityModel.get('warned')) return;  // Only warn once
+        baton.view.securityModel.set('warned', true);
         require(['io.ox/core/tk/dialogs'], function (dialogs) {
             var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
             dialog.header($('<h4>').text(gt('HTML Formatted Email')));
@@ -53,7 +68,7 @@ define('oxguard/mail/options_new', [
             .on('ok', function () {
                 baton.config.set('editorMode', 'text');
                 baton.config.on('change:editorMode', function () {
-                    if ((baton.config.get('editorMode') === 'html') && (baton.view.securityModel.get('PGPFormat') === 'inline')) {
+                    if ((baton.config.get('editorMode') === 'html') && (baton.view.securityModel.get('pgpInline'))) {
                         var dialog2 = new dialogs.CreateDialog({ width: 450, height: 300, center: true });
                         dialog2.header($('<h4>').text(gt('HTML Formatted Email')));
                         var warn = $('<p>').append(gt('HTML format is not recommended when using PGP Inline'));
@@ -79,25 +94,16 @@ define('oxguard/mail/options_new', [
     }
 
     function createOptions(baton, count) {
-        if (window.oxguarddata.settings.oxguard === undefined) {  // If we don't yet have response from the Guard backend, check every second then handle
-            if (count === undefined) count = 0;
-            if (count > 10) return;  // limit our loop to 10 seconds
-            window.setTimeout(function () {
-                count++;
+        if (!ox.guard.isLoaded()) {
+            coreUtil.addOnLoaded(function () {
                 createOptions(baton, count);
-            }, 1000);
+            });
+            return;
         }
-
         if (window.oxguarddata.action === 'sendfile') { // If it is going to be sending already encrypted file, then don't add encryption options
             window.oxguarddata.action = null;
             return;
         }
-        if (window.oxguarddata.sentfolder === undefined) { // Get sent folder data for sending
-            require(['settings!io.ox/mail']).done(function (settings) {
-                window.oxguarddata.sentfolder = settings.get('folder/sent');
-                window.oxguarddata.draftfolder = settings.get('folder/drafts');
-            });
-        }
 
         var securityModel = baton.view.securityModel;
 
@@ -107,11 +113,11 @@ define('oxguard/mail/options_new', [
                 securityModel.setInline();
                 window.oxguarddata.replyInline = null;
             }
-            if (securityModel.get('PGPFormat') === undefined) { // If not previously defined
-                securityModel.set('PGPFormat', getType(window.oxguarddata.current));
+            if (securityModel.get('pgpInline') === undefined) { // If not previously defined
+                securityModel.set('pgpInline', getType(window.oxguarddata.current) === 'inline');
             }
             securityModel.set('encrypt', true);
-            if (window.oxguarddata.settings.oxguard === false || window.oxguarddata.settings.secureReply === true) {
+            if (ox.guard.getSettings().secureReply === true) {
                 baton.view.$el.find('#statuslock')
                     .attr('class', lockclass)
                     .click(false)
@@ -123,37 +129,51 @@ define('oxguard/mail/options_new', [
 
         var headers = baton.model.get('headers');
         if (headers && (headers['X-OxGuard-Sign'] === 'true')) {
-            securityModel.set('PGPSignature', true);
+            securityModel.set('sign', true);
         }
 
         createlock(baton);
+
         // Guard bug GUARD-200, deleted user still has defaults applied.  Verify configured before applying
-        if (baton.config.get('newmail') === true && coreUtil.hasGuardMailCapability() && coreUtil.isGuardConfigured()) {  // New email doesn't have recips yet.  Check to see if there are defaults
-            // If default is to use guard, go ahead and lock
-            if (settings.get('defaultEncrypted')) {
-                securityModel.set('encrypt', true);
-                core.lock(baton);
-            } else securityModel.set('encrypt', false);
+        if (baton.config.get('newmail') === true && ((coreUtil.hasGuardMailCapability() && coreUtil.isGuardConfigured()) || coreUtil.hasSmime())) {  // New email doesn't have recips yet.  Check to see if there are defaults
+            if (settings.get('defaultSmime') && settings.get('smime') && coreUtil.hasSmime()) {
+                securityModel.set('smime', true);
+            }
             if (settings.get('defaultInline')) {
-                if (settings.get('defaultEncrypted')) {
-                    securityModel.setInline();
-                    warnHTML(baton);
-                } else {
-                    securityModel.setInline();
-                }
+                securityModel.setInline();
             } else securityModel.setMime();
+
             baton.config.unset('newmail');
 
             if (settings.get('defaultSign')) {
-                securityModel.set('PGPSignature', true);
+                securityModel.set('sign', true);
             }
         }
 
-        securityModel.on('change:PGPFormat change:encrypt', function () {
+        if (baton.config.get('type') !== 'new' && baton.config.get('type') !== 'edit') {  // set for replies, forward
+            if (coreUtil.hasSmime() || coreUtil.hasGuardMailCapability()) {
+                var original = _.isArray(baton.model.original) ? baton.model.original[0] : baton.model.original;
+                var origSmime = original && original.security && (original.security.type === 'SMIME');
+                if ((settings.get('defaultSmime') || origSmime) && settings.get('smime') && coreUtil.hasSmime()) {
+                    securityModel.set('smime', true);
+                }
+                if (settings.get('defaultSign')) {
+                    securityModel.set('sign', true);
+                }
+            }
+        }
+
+        securityModel.on('change:pgpInline change:encrypt', function () {
             warnHTML(baton);
         });
 
-        securityModel.on('change:PGPFormat', function () {
+        // If default is to use guard, go ahead and lock
+        if (settings.get('defaultEncrypted')) {
+            securityModel.set('encrypt', true);
+            core.lock(baton);
+        }
+
+        securityModel.on('change:pgpInline', function () {
             securityModel.set('encrypt', true);
         });
 
@@ -174,12 +194,12 @@ define('oxguard/mail/options_new', [
                 return;
             }
         }
-        require(['oxguard/mail/pubkey', 'io.ox/core/notifications', 'io.ox/mail/compose/api'], function (pk, notify, composeApi) {
-            pk.getPubKeyAttachment()
-            .done(function (key) {
+        require(['oxguard/api/keys', 'io.ox/core/notifications', 'io.ox/mail/compose/api'], function (keysAPI, notify, composeApi) {
+            keysAPI.download({ keyType: 'public' })
+            .done(function (data) {
                 try {
-                    var file = new Blob([key.content], { type: 'application/pgp-keys' });
-                    file.name = key.filename;
+                    var file = new Blob([data.key], { type: 'application/pgp-keys' });
+                    file.name = 'public.asc';
                     composeApi.space.attachments.add(baton.model.get('id'), { file: file })
                     .then(function (data) {
                         baton.model.attachFiles(data);
