@@ -1,11 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/oxguard_mail_compose_core', [
@@ -56,6 +68,11 @@ define('oxguard/mail/oxguard_mail_compose_core', [
                     $(location).find('.close').before(gKey);
                     createTooltip('guest', gKey, location);
                     break;
+                case 'smime' :
+                    key.addClass('trusted_key');
+                    $(location).find('.close').before(key);
+                    createTooltip(info, key, location);
+                    break;
                 case 'fail' :
                     $(location).find('.close').before(failicon);
 
@@ -70,7 +87,15 @@ define('oxguard/mail/oxguard_mail_compose_core', [
     function createTooltip(data, loc, t) {
         require(['oxguard/pgp/keyDetails'], function (pubKeys) {
             var div = $('<div>');
-            if (data === 'new') {  // New recipient
+            if (data.result === 'smime') {
+                div.append(gt('S/MIME public certificate'), '<br>');
+                div.append(gt('Expires: %s', new Date(data.key.expires).toLocaleDateString()), '<br>');
+                div.append(gt('Serial: %s', data.key.serial));
+            } else if (data === 'new') {  // New recipient
+                div.append(gt('Key will be created upon sending.'));
+            } else if (data === 'guest') {
+                div.append(gt('Will create new guest account for %s', ox.guard.getName()));
+            } else if (data === 'new') {  // New recipient
                 div.append(gt('Key will be created upon sending.'));
             } else if (data === 'guest') {
                 div.append(gt('Will create new guest account for %s', window.oxguarddata.productName));
@@ -81,6 +106,7 @@ define('oxguard/mail/oxguard_mail_compose_core', [
                 div.append(data.keySource.trusted ? gt('Trusted') : gt('Untrusted Source'));
                 div.addClass(data.keySource.trusted ? 'trusted_key' : 'untrusted_key');
             }
+
             $(loc).tooltip({
                 title: div.html(),
                 trigger: 'hover focus',
