@@ -1,11 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/mail/oxguard_mail_password', [
@@ -23,17 +35,6 @@ define('oxguard/mail/oxguard_mail_password', [
 
     ////////////////////////   RECEIVE / READ
 
-    function loadKeyClick(evt) {
-        var file = evt.target.files[0];
-        var reader = new FileReader();
-
-        reader.onload = function () {
-            //encrPrivKey = event.target.result;
-            $('#privKeyButton').html(gt('Loaded'));
-        };
-        reader.readAsText(file);
-    }
-
     // Unified inbox combines folder and email ID, returns email id
     function getId(baton) {
         var id = decodeURIComponent(baton.data.id);
@@ -45,13 +46,35 @@ define('oxguard/mail/oxguard_mail_password', [
         return (id);
     }
 
+    function getType(baton) {
+        if (baton.data.security_info && baton.data.security_info.type) { return baton.data.security_info.type; }
+        return 'unkown';
+    }
+
+    function getPrompt(baton) {
+        // Generic
+        if ((oxguard.hasGuardMail() && !oxguard.hasSmime()) || // Has guard-mail, but not smime
+            (oxguard.hasSmime() && !oxguard.hasGuardMail()) || // Has smime, but not guard-mail
+            (getType(baton) === 'PGP' && !oxguard.hasSmimeEnabled())) {  // Has both, but type is PGP and doesn't have smime enabled in settings
+            return gt('Secure Email, enter your %s security password.', ox.guard.getName());
+        }
+        if (getType(baton) === 'PGP') {
+            return gt('PGP encrypted email, enter the password for the PGP key.');
+        }
+        if (getType(baton) === 'SMIME') {
+            return gt('S/MIME encrypted email, enter the password for the S/MIME key.');
+        }
+        return gt('Uncertain encryption type');
+
+    }
+
     function passwordPrompt(baton, badpass, location, goFunction, localOnly) {
         var id = getId(baton);
         var passwordBoxView = new PasswordView.view({ 'id': 'oxgrpass' + id, 'class': 'password_prompt', 'validate': false });
         var passwordbox = passwordBoxView.getProtected().css('display', 'inline');
         var grdPasswordPrompt = $('<div class="alert og_password"/>');
         //#. %s product Name
-        var mainpassprompt = $('<label style="font-weight:bold;" for="oxgrpass' + id + '">' + gt('Secure Email, enter your %s security password.', window.oxguarddata.productName) + '</span><br/><div style="height:10px;"/>');
+        var mainpassprompt = $('<label style="font-weight:bold;" for="oxgrpass' + id + '">' + getPrompt(baton) + '</span><br/><div style="height:10px;"/>');
         if (_.device('small')) {
             passwordbox.css('width', '150px');
         }
@@ -59,7 +82,7 @@ define('oxguard/mail/oxguard_mail_password', [
         var passButton = $('<button class="btn btn-primary oxguard_passbutton" type="button">' + gt('OK') + '</button><br/>');
         var placeholder = $('<span></span><br/>');
         //#. 'Keep me logged into guard' is followed by dropdown box specifying number of minutes or indefinite, %s product name
-        var remembertext = $('<label class="checkbox custom small" for="rememberpass">' + gt('Keep me logged into %s', window.oxguarddata.productName) + '</label>');
+        var remembertext = $('<label class="checkbox custom small" for="rememberpass">' + gt('Keep me logged into %s', ox.guard.getName()) + '</label>');
         var checkbox = $('<input type="checkbox" id="rememberpass" name="rememberpass' + id + '" value="true" style="margin-top:3px;"/>');
         var rememberpass = $('<div>').append(remembertext.append(checkbox));
         var duration = $('<select id="duration' + id + '" class="og_duration"><option value="10">' + gt('10 minutes') + '</option>' +
@@ -82,7 +105,7 @@ define('oxguard/mail/oxguard_mail_password', [
 
         var forgotDiv = $('<div class="og_forgot" style="display:none">');
 
-        if (window.oxguarddata.recoveryAvail) {  // Display password help if available
+        if (ox.guard.get('recoveryAvail')) {  // Display password help if available
             var forgotLink = $('<a href="#">').append(gt('Forgot Password'));
             forgotLink.click(function (e) {
                 e.preventDefault();
@@ -95,18 +118,7 @@ define('oxguard/mail/oxguard_mail_password', [
         }
 
         var cont = $('<br/><div class="oxguard_error" id = "error' + id + '" style="display:none;"></div>');
-        if (window.oxguarddata.passcode === 'NoPrivate') {
-            var btn = $('<button class="btn og_getkey" id="privKeyButton' + id + '">' + gt('Select Key Location') + '</button>');
 
-            var input = $('<input type="file" id="files' + id + '" name="files[] style="padding:10px;visibility:hidden;position:absolute;top-50px;left:-50px;"/>');
-            btn.click(function () {
-                input.click();
-            });
-            input.change(function (evt) {
-                loadKeyClick(evt);
-            });
-            placeholder.append(btn.after(input));
-        }
         passButton.click(function () {
             go();
         });
@@ -143,7 +155,7 @@ define('oxguard/mail/oxguard_mail_password', [
             }
             passwordbox.parent().busy();
             passButton.prop('disabled', true);
-            oxguard.savePassword(password, duration)
+            oxguard.savePassword(password, duration, getType(baton))
             .done(function () {
                 goFunction(password);
             })
@@ -152,11 +164,13 @@ define('oxguard/mail/oxguard_mail_password', [
                 passwordbox.parent().idle();
                 passButton.prop('disabled', false);
                 require(['io.ox/core/notifications'], function (notifications) {
-                    if (data.auth && data.auth.indexOf('Lockout') > -1) {
+                    if (data.error && data.code === 'GRD-MW-0005') {
                         notifications.yell('error', gt('Temporary Lockout'));
-                    } else {
+                    } else if (data.error && data.code === 'GRD-MW-0003') {
                         notifications.yell('error', gt('Bad password'));
-                        if (window.oxguarddata.recoveryAvail) $('.og_forgot').show();
+                        if (ox.guard.get('recoveryAvail')) $('.og_forgot').show();
+                    } else {
+                        notifications.yell('error', data.error);
                     }
                 });
             });
