@@ -1,17 +1,40 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 define('oxguard/mail/register_compose', [
     'io.ox/core/extensions',
     'gettext!oxguard',
     'io.ox/backbone/mini-views/dropdown',
     'oxguard/mail/oxguard_mail_compose_core',
     'oxguard/util',
-    'pgp_mail/toggle-encryption',
+    'oxguard/mail_lock/toggle-encryption',
     'io.ox/backbone/mini-views/helplink',
     'oxguard/mail/keymanager',
     'settings!oxguard',
     'oxguard/mail/security_model',
     'io.ox/mail/compose/api',
+    'oxguard/oxguard_core',
     'less!oxguard/mail/style'
-], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings, SecurityModel, composeAPI) {
+], function (ext, gt, Dropdown, core, util, ToggleEncryption, HelpView, keyman, settings, SecurityModel, composeAPI, guard_core) {
 
     'use strict';
 
@@ -26,8 +49,9 @@ define('oxguard/mail/register_compose', [
             var node = this;
             var securityModel = new SecurityModel(baton.model.get('security'), baton.model);
             baton.view.securityModel = securityModel;
-            var view = new ToggleEncryption.ViewMobile({
-                model: securityModel
+            var view = new ToggleEncryption.View({
+                model: securityModel,
+                mailModel: baton.model
             }, baton.model);
             view.noLinkMail(baton.view);
             baton.view.toggleEncryption = view;
@@ -39,10 +63,18 @@ define('oxguard/mail/register_compose', [
 
     ext.point('io.ox/mail/compose/menu-mobile').replace({
         id: 'security',
-        index: 100,
+        index: 10000,
         draw: function (baton) {
             var node = this;
             if (_.device('!smartphone')) return;
+            baton.view.securityModel.on('change:smime', function () {
+                baton.config.set('gkeys', undefined);
+                require(['oxguard/mail/keymanager'], function (keyman) {
+                    keyman.checkAll(baton);
+                });
+                $('.security-mobile').remove();
+                node.append(drawDropDownMobile(baton, $(node)));
+            });
             drawDropDownMobile(baton, $(node));
         }
     });
@@ -50,7 +82,7 @@ define('oxguard/mail/register_compose', [
     // Desktop only
     ext.point('io.ox/mail/compose/fields').extend({
         id: 'info-and-options',
-        index: 900,
+        index: 400,
         draw: function (baton) {
             if (_.device('smartphone')) return;
             if (!util.hasCryptoCapability()) return;
@@ -66,48 +98,84 @@ define('oxguard/mail/register_compose', [
             // toggle
             update();
             baton.view.securityModel.on('change:encrypt', update);
+            baton.view.securityModel.on('change:smime', update);
+            baton.model.on('change:gkeys', update);
             function update() {
+                if (guard_core.hasPGPandSmime() && baton.view.securityModel.get('encrypt')) {
+                    var smime = baton.view.securityModel.get('smime');
+                    node.find('.text').html(smime ? gt('This email will be encrypted with S/MIME') : gt('This email will be encrypted with PGP'));
+                } else {
+                    node.find('.text').html(gt('This email will be encrypted.'));
+                }
+
+                var keys = baton.config.get('gkeys');
+                if (keys) {
+                    var fail = false;
+                    for (var email in keys) {
+                        if (keys[email].result === 'fail') fail = true;
+                    }
+                    node.toggleClass('stripes-green', !fail).toggleClass('stripes-red', fail);
+                    if (fail) {
+                        node.find('.text').html(gt('Unable to encrypt until all recipient keys available.'));
+                    }
+                }
+
                 node.toggleClass('hidden', !baton.view.securityModel.get('encrypt'));
             }
 
             // dropdown
-            if (!window.oxguarddata || !window.oxguarddata.settings || !window.oxguarddata.settings.oxguard) return;
-            var dropdown = new Dropdown({
-                model: baton.view.securityModel,
-                label: gt('Options'),
-                caret: true
-            })
-            .header(gt('Security'))
-            .option('PGPSignature', true, gt('Sign email'))
-            .option('PubKey', true, gt('Attach my public key'));
-
-            if (settings.get('advanced')) {
-                dropdown
-                //#. Format of the email, HTML or Plaintext
-                .header(gt('PGP Format'))
-                .option('PGPFormat', 'mime', gt('Mime'))
-                .option('PGPFormat', 'inline', gt('Inline'));
-            }
-
-            //  Help icon
-            dropdown.render().$el
-                .addClass('security-options')
-                .find('ul').prepend(
-                    new HelpView({
-                        base: 'help',
-                        iconClass: 'fa-question-circle',
-                        href: 'ox.appsuite.user.sect.guard.email.send.html',
-                        tabindex: '-1'
-                    }).render().$el.addClass('guard-help-icon').addClass('guardhelp')
-                );
-
-            node.append(dropdown.$el);
+            if (!ox.guard.hasGuardMail() && !ox.guard.hasSmime()) return;
+            var dropdown = drawDropdown(baton);
+            node.append(dropdown);
+            baton.view.securityModel.on('change:smime', function () {
+                baton.config.set('gkeys', undefined);
+                baton.model.save();
+                require(['oxguard/mail/keymanager'], function (keyman) {
+                    keyman.checkAll(baton);
+                });
+                $('.pgpDropdownOptions').remove();
+                node.append(drawDropdown(baton));
+            });
         }
     });
 
+    function drawDropdown(baton) {
+        var dropdown = new Dropdown({
+            model: baton.view.securityModel,
+            label: gt('Options'),
+            caret: true
+        })
+        .header(gt('Security'))
+        .option('sign', true, gt('Sign email'));
+        if (!baton.view.securityModel.get('smime')) {
+            dropdown.option('PubKey', true, gt('Attach my public key'));
+        }
+        if (settings.get('advanced')) {
+            if (!baton.view.securityModel.get('smime')) {
+                dropdown
+                //#. Format of the email, HTML or Plaintext
+                .header(gt('PGP Format'))
+                .option('pgpInline', false, gt('Mime'))
+                .option('pgpInline', true, gt('Inline'));
+            }
+        }
+        //  Help icon
+        dropdown.render().$el
+            .addClass('security-options')
+            .find('ul').prepend(
+                new HelpView({
+                    base: 'help',
+                    href: 'ox.appsuite.user.sect.guard.email.send.html',
+                    tabindex: '-1'
+                }).render().$el.addClass('guard-help-icon')
+            );
+        dropdown.$el.find('[data-name="pgpInline"]').attr('data-toggle', false);
+        return dropdown.$el.addClass('pgpDropdownOptions');
+    }
+
     ext.point('io.ox/mail/compose/composetoolbar').extend({
         id: 'lock',
-        index: 400,
+        index: 900,
         draw: function (baton) {
             if (_.device('smartphone')) return;
             // TODO check for encr reply
@@ -144,7 +212,7 @@ define('oxguard/mail/register_compose', [
                 securityModel = baton.view.securityModel;
 
             // sync updates of intermediateModel (dropdown) and securityModel
-            ['PGPSignature', 'PubKey'].forEach(function (key) {
+            ['sign', 'PubKey', 'smime'].forEach(function (key) {
                 intermediateModel.set(key, securityModel.get(key));
                 intermediateModel.on('change:' + key, function name() {
                     securityModel.set(key, intermediateModel.get(key));
@@ -156,10 +224,19 @@ define('oxguard/mail/register_compose', [
             var node = this.data('view')
                 .divider()
                 .header(gt('Security'));
-            if (util.hasGuardMailCapability()) {
-                node.option('PGPSignature', true, gt('Sign email'));
+            if (guard_core.hasPGPandSmime()) {
+                node.option('smime', true, gt('Use S/MIME'), { radio: true });
+                node.option('smime', false, gt('Use PGP'), { radio: true });
             }
-            node.option('PubKey', true, gt('Attach my public key'));
+            node.option('sign', true, gt('Sign email'));
+            if (guard_core.hasGuardMail()) {
+                node.option('PubKey', true, gt('Attach my public key'));
+                securityModel.on('change:smime', function (m) {
+                    node.$el.find('[data-name="PubKey"]').css('display', m.get('smime') ? 'none' : 'block');
+                });
+            }
+            node.$ul.find('[data-name="smime"]').attr('data-toggle', 'false');
+            node.$ul.find('[data-name="pgpInline"]').attr('data-toggle', 'false');
 
         }
     });
@@ -251,6 +328,7 @@ define('oxguard/mail/register_compose', [
             index: 100,
             before: 'busy:start',
             perform: function (baton) {
+                //baton.model.set('security', baton.view.securityModel.toJson());
                 if (!baton.view.securityModel.get('encrypt')) return true;
                 var def = $.Deferred();
                 if (isReady(baton)) {
@@ -271,9 +349,20 @@ define('oxguard/mail/register_compose', [
                 var security = baton.model.get('security');
                 if (security.sign) {
                     require(['oxguard/auth'], function (auth) {
+                        var prompt = gt('Please enter your %s password to sign this email.', ox.guard.getName());
+                        if (util.hasGuardMailCapability() && util.hasSmime()) {  // If has both types, get specific reference
+                            if (security.type.toLowerCase() === 'pgp') {
+                                prompt = gt('Please enter your PGP password to sign this email.');
+                            }
+                            if (security.type.toLowerCase() === 'smime') {
+                                prompt = gt('Please enter your S/MIME password to sign this email.');
+                            }
+                        }
+
                         var options = {
-                            optPrompt: gt('Please enter your %s password to sign this email.', window.oxguarddata.productName),
-                            minSingleUse: true
+                            optPrompt: prompt,
+                            minSingleUse: true,
+                            type: security.type
                         };
                         auth.authorize(baton, options)
                         .done(function (auth) {
@@ -318,7 +407,7 @@ define('oxguard/mail/register_compose', [
                         found = true;
                         require(['oxguard/auth'], function (auth) {
                             var options = {
-                                optPrompt: gt('There appears to be an encrypted attachment.  Please enter your %s password to decode the attachment for sending.', window.oxguarddata.productName),
+                                optPrompt: gt('There appears to be an encrypted attachment.  Please enter your %s password to decode the attachment for sending.', ox.guard.getName()),
                                 minSingleUse: true
                             };
                             auth.authorize(baton, options)
@@ -345,7 +434,7 @@ define('oxguard/mail/register_compose', [
             perform: function (baton) {
                 if (baton.error && containsError(baton.errorCode, baton.error)) {
                     handleFail(baton);
-                    handleReauth(gt('Please re-enter your %s password before sending.', window.oxguarddata.productName), baton)
+                    handleReauth(gt('Please re-enter your %s password before sending.', ox.guard.getName()), baton)
                     .done(function () {
                         updateAuth(baton.model).then(function () {
                             baton.view.send();
@@ -372,7 +461,7 @@ define('oxguard/mail/register_compose', [
         perform: function (baton) {
             if (baton.error && containsError(baton.errorCode, baton.error)) {
                 handleFail(baton);
-                handleReauth(gt('Please re-enter your %s password before saving.', window.oxguarddata.productName), baton)
+                handleReauth(gt('Please re-enter your %s password before saving.', ox.guard.getName()), baton)
                 .done(function () {
                     updateAuth(baton.model);
                 });
@@ -389,7 +478,7 @@ define('oxguard/mail/register_compose', [
         handler: function (baton) {
             if (baton.result && containsError(baton.result.code, baton.result.error)) {
                 baton.handled = $.Deferred();
-                return handleReauth(gt('Please enter your %s password to edit this encrypted draft.', window.oxguarddata.productName), baton)
+                return handleReauth(gt('Please enter your %s password to edit this encrypted draft.', ox.guard.getName()), baton)
                 .then(function () {
                     // TODO: this needs proper converters and serializers/deserializers for compose model <=> guard model <=> JSON
                     var security = baton.model.get('security');
@@ -397,7 +486,11 @@ define('oxguard/mail/register_compose', [
                     delete security.authentication;
                     return composeAPI.space.update(baton.model.get('id'), { security: security });
                 }).then(function () {
-                    baton.handled.resolve(composeAPI.space.get(baton.model.get('id')));
+                    composeAPI.space.get(baton.model.get('id')).then(function (data) {
+                        var security = baton.model.get('security');
+                        data.security = security;
+                        baton.handled.resolve(data);
+                    });
                 }).catch(function (error) {
                     baton.handled.reject(error);
                 });
@@ -415,7 +508,7 @@ define('oxguard/mail/register_compose', [
                 if (e.error && e.code) {
                     if (containsError(e.code, e.error)) {
                         var model = this;
-                        handleReauth(gt('Please re-enter your %s password before saving.', window.oxguarddata.productName), baton)
+                        handleReauth(gt('Please re-enter your %s password before saving.', ox.guard.getName()), baton)
                         .done(function () {
                             updateAuth(model).then(function () {
                                 model.save();
@@ -439,7 +532,7 @@ define('oxguard/mail/register_compose', [
                 var security = baton.model.get('security');
                 require(['oxguard/auth'], function (auth) {
                     var options = {
-                        optPrompt: gt('Please re-enter your %s password.', window.oxguarddata.productName),
+                        optPrompt: gt('Please re-enter your %s password.', ox.guard.getName()),
                         minSingleUse: true,
                         forceRelogin: true
                     };
@@ -465,32 +558,31 @@ define('oxguard/mail/register_compose', [
 
     // Drawing dropdown options for security
     function drawDropDownMobile(baton, node) {
-        if (window.oxguarddata && window.oxguarddata.settings) {
-            if (window.oxguarddata.settings.oxguard) {
-                var dropdown = new Dropdown({ model: baton.view.securityModel, label: gt('Security'), caret: true });
-                if (settings.get('advanced')) {
-                    dropdown
-                        .header(gt('PGP'));
-                } else {
-                    dropdown
-                    .header(gt('Security'));
-                }
-                dropdown
-                    .option('encrypt', true, (settings.get('advanced') ? gt('Encrypt') : gt('Secure')))
-                    .option('PGPSignature', true, gt('Sign'));
-                if (settings.get('advanced')) {
-                    dropdown
-                    //#. Format of the email, HTML or Plaintext
-                    .header(gt('Format'))
-                    .option('PGPFormat', 'mime', gt('PGP Mime'))
-                    .option('PGPFormat', 'inline', gt('PGP Inline'));
-                    dropdown
-                    .header(gt('Keys'))
-                    .option('PubKey', true, gt('Attach my key'));
-                }
-                node.addClass('security-mobile')
-                    .append(dropdown.render().$el.addClass('text-left'));
+        if (ox.guard.hasGuardMail() || guard_core.hasSmime()) {
+            var dropdown = new Dropdown({ model: baton.view.securityModel, label: gt('Security'), caret: true });
+            dropdown
+                .header(gt('Security'));
+            if (guard_core.hasPGPandSmime()) {
+                dropdown.option('smime', true, gt('Use S/MIME'));
+                dropdown.option('smime', false, gt('Use PGP'));
             }
+            dropdown
+                .option('encrypt', true, (settings.get('advanced') ? gt('Encrypt') : gt('Secure')))
+                .option('sign', true, gt('Sign'));
+            if (guard_core.hasGuardMail() && settings.get('advanced') && !baton.view.securityModel.get('smime')) {
+                dropdown
+                //#. Format of the email, HTML or Plaintext
+                .header(gt('Format'))
+                .option('pgpInline', false, gt('PGP Mime'))
+                .option('pgpInline', true, gt('PGP Inline'));
+                dropdown
+                .header(gt('Keys'))
+                .option('PubKey', true, gt('Attach my key'));
+            }
+            node
+                .append(dropdown.render().$el.addClass('text-left').addClass('security-mobile'));
+            node.$ul.find('[data-name="smime"]').attr('data-toggle', 'false');
+            node.$ul.find('[data-name="pgpInline"]').attr('data-toggle', 'false');
         }
     }
 
@@ -542,10 +634,9 @@ define('oxguard/mail/register_compose', [
 
     // Check if response code and error string contain auth error
     function containsError(code, string) {
-        if (code === 'GRD-MW-0001') return true;  // Midleware Auth error
-        if (code !== 'GUARD-0003') return false;
+        if (code === 'GRD-0002' || code === 'GRD-AUTH-0002') return true; // Midleware Auth error
         return (string && string !== null &&
-            (string.indexOf('GRD-AUTH-0002') > -1 || string.indexOf('GRD-PGP-0005') > -1));
+                    ((string.indexOf('GRD-AUTH-0002') > -1 || string.indexOf('GRD-PGP-0005') > -1) || (string.indexOf('ENCRYPT-0006') > -1)));
     }
 
     function handleFail(baton) {
@@ -566,7 +657,7 @@ define('oxguard/mail/register_compose', [
     }
 
     function handleReauth(prompt, baton) {
-        window.oxguarddata.passcode = null;  // wipe stored auth token
+        ox.guard.clearAuth();  // wipe stored auth token
         var def = $.Deferred();
         require(['oxguard/auth'], function (auth) {
             var security = baton.model.get('security');
