@@ -1,3 +1,25 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 /**
  * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
  * LICENSE. This work is protected by copyright and/or other applicable
@@ -89,7 +111,7 @@ define('oxguard/pgp/autocrypt/autocryptStartupView', [
         http.post(ox.apiRoot + '/oxguard/keys?action=importAutoCryptKeys', params, userdata)
         .done(function (data) {
             if (data && data.data === 'Success') {
-                window.oxguarddata.passcode = null;
+                ox.guard.clearAuth();
                 yell('success', gt('Keys imported successfully'));
                 lastPass = undefined;
             } else {
