@@ -1,3 +1,25 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 /**
  * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
  * LICENSE. This work is protected by copyright and/or other applicable
@@ -272,12 +294,12 @@ define('oxguard/pgp/uploadkeys', [
         var newogpassword2 = new PasswordView.view({ 'id': 'guardpassword2', 'class': 'password_prompt', 'validate': true }).getProtected();
         var pgpPassword = new PasswordView.view({ 'id': 'pgppassword', 'class': 'password_prompt' }).getProtected();
         var hint = $('<td>');
-        var pw1 = $('<tr>').append($('<td class="pw">').append('<label for="guardpassword">' + gt('Enter new password for the key:') + '</label>')).append($('<td>').append(newogpassword));
-        var pw2 = $('<tr>').append($('<td class="pw">').append('<label for="guardpassword2">' + gt('Confirm Password:') + '</label>')).append($('<td>').append(newogpassword2));
+        var pw1 = $('<tr>').append($('<td class="pw">').append('<label for="guardpassword">' + gt('Enter a new password to use.  You will be prompted for this password when this key is used to decrypt an item:') + '</label>')).append($('<td>').append(newogpassword));
+        var pw2 = $('<tr>').append($('<td class="pw">').append('<label for="guardpassword2">' + gt('Confirm the new password:') + '</label>')).append($('<td>').append(newogpassword2));
         var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
         var table = $('<table class="og_password_prompt"/>')
         .append(noSaveWorkAround)
-        .append($('<tr>').append($('<td class="pw"><label for="pgppassword">' + gt('Private key password for the key you are uploading:') + '</label></td>')).append($('<td>').append(pgpPassword)))
+        .append($('<tr>').append($('<td class="pw"><label for="pgppassword">' + gt('Password used to protect the file you are uploading:') + '</label></td>')).append($('<td>').append(pgpPassword)))
         .append(pw1)
         .append(pw2)
         .append($('<tr>').append('<td>').append(hint));
@@ -299,9 +321,9 @@ define('oxguard/pgp/uploadkeys', [
             deferred.reject(gt('Passwords not equal'));
             return deferred;
         }
-        if (window.oxguarddata.settings.min_password_length !== undefined) {  // Check min password length
-            if (guard.trim().length < window.oxguarddata.settings.min_password_length) {
-                deferred.reject(gt('New password must be at least %s characters long', window.oxguarddata.settings.min_password_length));
+        if (ox.guard.getSettings().min_password_length !== undefined) {  // Check min password length
+            if (guard.trim().length < ox.guard.getSettings().min_password_length) {
+                deferred.reject(gt('New password must be at least %s characters long', ox.guard.getSettings().min_password_length));
                 return deferred;
             }
         } else if (guard.trim().length < 2) { // If no min defined, make sure at least 2 characters there
@@ -360,7 +382,8 @@ define('oxguard/pgp/uploadkeys', [
         upload: upload,
         uploadPrivate: uploadPrivate,
         uploadPublicKey: uploadPublicKey,
-        uploadExternalKey: uploadExternalKey
+        uploadExternalKey: uploadExternalKey,
+        createPrompts: createPrompts
     };
 
 });
