@@ -1,11 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
 
 define('oxguard/register', [
@@ -13,34 +25,21 @@ define('oxguard/register', [
     'gettext!oxguard',
     'settings!oxguard',
     'io.ox/core/capabilities',
+    'oxguard/core/guardModel',
     'less!oxguard/style'
-], function (ext, gt, settings, capabilities) {
+], function (ext, gt, settings, capabilities, GuardModel) {
 
     'use strict';
 
-    var productName = ox.serverConfig['guard.productName'] === undefined ? settings.get('productName') : ox.serverConfig['guard.productName'];
-    if (productName === undefined || productName === 'undefined' || productName === '') {
-        productName = 'Guard';
-    }
-
     var oxguarddata = {
         passcode: null,
-        settings:  {},
-        productName: sanitize(productName)
+        settings:  {}
     };
 
+    ox.guard = new GuardModel(oxguarddata);
     window.oxguarddata = oxguarddata;
 
-    if (settings.get('pgplocal') === true) {  // Load local keys if set
-        require(['pgp_local/register'], function (pgpLocal) {
-            pgpLocal.loadPrivate();
-        });
-    }
-
     // Load data generated at compile (build version, etc)
-    require(['oxguard/oxguard_data'], function (generatedData) {
-        _.extend(window.oxguarddata, generatedData);
-    });
 
     // Login section
     sendauth(''); // initial login, no password yet
@@ -54,31 +53,28 @@ define('oxguard/register', [
     // Sends first login to get settings info, key data
     function sendauth(pass) {
         require(['oxguard/oxguard_core'], function (oxguard) {
-            oxguard.auth(ox.user_id, pass)
+            var typeLogin = capabilities.has('guard') ? 'pgp' : 'smime';
+            oxguard.auth(ox.user_id, pass, typeLogin)
             .done(function (data) {
                 try {
-                    if (data.error) {
-                        console.error(data.error);
-                        console.debug('Unable to connect to Encryption Server');
-                        return;
-                    }
-                    oxguarddata = _.extend(window.oxguarddata, checkLanguages(data));
-                    oxguarddata.loaded = true;
+                    require(['oxguard/oxguard_data'], function (generatedData) {
+                        _.extend(data, generatedData);
+                        ox.guard.loadData(data);
+                    });
+
                     if (data.auth.length > 20 && !(/^Error:/i.test(data.auth))) { // If good code comes back, then store userid
-                        oxguarddata.userid = ox.user_id;
-                        oxguarddata.passcode = data.auth;
+                        ox.guard.setauth(data.auth, typeLogin);
                     } else { // If bad code, then log and mark oxguard.user_id as -1
                         if (/^((Error)|(Bad)|(Lockout))/i.test(data.auth)) {
-                            oxguarddata.passcode = null;
+                            ox.guard.clearAuth();
                         } else {
-                            oxguarddata.passcode = data.auth;
+                            ox.guard.setAuth(data.auth, typeLogin);
                         }
                         if (data.error) {
                             require(['io.ox/core/notifications'], function (notify) {
-                                notify.yell('error', productName + '\r\n' + data.error);
+                                notify.yell('error', ox.guard.getName() + '\r\n' + data.error);
                             });
                         }
-                        oxguarddata.userid = -1;
                     }
                     if (settings.get('defaultEncrypted') === undefined) {
                         require(['oxguard/settings/pane'], function (defaults) {
@@ -86,21 +82,9 @@ define('oxguard/register', [
                         });
                     }
                     if (ox.context_id === 0) ox.context_id = data.cid; // If the cid wasn't loaded, update from backend
-                    oxguarddata.baton = window.oxguarddata.baton;
-                    oxguarddata.recovery = data.recoveryAvail === undefined ? !data.noRecovery : data.recoveryAvail;
-                    window.oxguarddata = oxguarddata;
-                    // Check for any pending onload actions
-                    if (oxguarddata.onload) {
-                        try {
-                            oxguarddata.onload.forEach(function (load) {
-                                load.call();
-                            });
-                            oxguarddata.onload = null;
-                        } catch (e) {
-                            console.error('Problem executing onload functions for Guard ' + e);
-                        }
-                    }
-                    if (sessionStorage !== null) { // If we were passed login info from login screen
+
+                    if (sessionStorage !== null) {
+                        // If we were passed login info from login screen
                         try {
                             if (sessionStorage.oxguard && (sessionStorage.oxguard !== 'null')) {
                                 var p = sessionStorage.oxguard;
@@ -124,28 +108,15 @@ define('oxguard/register', [
 
     }
 
-    // Parse out available languages, comparing Guard templates and UI available
-    function checkLanguages(data) {
-        var guardLanguages = data.lang;
-        var available = {};
-        for (var lang in guardLanguages) {
-            if (ox.serverConfig.languages[lang]) {
-                available[lang] = guardLanguages[lang];
-            }
-        }
-        data.lang = available;
-        return data;
-    }
-
     function doLogout(notify) {
         var def = $.Deferred();
-        window.oxguarddata.passcode = null;
-        require(['oxguard/oxguard_core'], function (oxguard) {
-            oxguard.saveAuthToSession('', -1)  // destroy auth token
-            .done(function () { // Destroy Guard mapping and auth-token
+        ox.guard.clearAuth();
+        require(['oxguard/api/auth'], function (authAPI) {
+            // Destroy Guard mapping and auth-token
+            authAPI.resetToken('none').done(function () {
                 if (notify) {
                     require(['io.ox/core/notifications'], function (notify) {
-                        notify.yell('success', gt('Logged out of %s', productName));
+                        notify.yell('success', gt('Logged out of %s', ox.guard.getName()));
                     });
                 }
             });
@@ -161,7 +132,7 @@ define('oxguard/register', [
             if (_.device('small') || capabilities.has('guest')) return;
             if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
                 this.append(
-                    this.link('GuardTour', gt('Guided tour for %s', window.oxguarddata.productName), function (e) {
+                    this.link('GuardTour', gt('Guided tour for %s', ox.guard.getName()), function (e) {
                         e.preventDefault();
                         require(['io.ox/core/tk/wizard', 'oxguard/tour/main'], function (Tour) {
                             Tour.registry.run('default/oxguard');
@@ -176,14 +147,13 @@ define('oxguard/register', [
         id: 'logoutOG',
         index: 50,
         extend: function () {
-            this.link('logoutOG', gt('Sign out %s', window.oxguarddata.productName), function (e) {
+            this.link('logoutOG', gt('Sign out %s', ox.guard.getName()), function (e) {
                 e.preventDefault();
-                window.oxguarddata.passcode = null;
+                ox.guard.clearAuth();
                 doLogout(true);
             });
             this.$el.on('shown.bs.dropdown', function () {
-                var pass = window.oxguarddata.passcode;
-                if (pass && pass.length > 10) {
+                if (ox.guard.hasAnyAuth()) {
                     $('[data-name="logoutOG"]').show();
                 } else {
                     $('[data-name="logoutOG"]').hide();
@@ -192,9 +162,14 @@ define('oxguard/register', [
         }
     });
 
-    function sanitize(data) {
-        var regex = new RegExp('<(?:!--(?:(?:-*[^->])*--+|-?)|script\\b(?:[^"\'>]|"[^"]*"|\'[^\']*\')*>[\\s\\S]*?</script\\s*|style\\b(?:[^"\'>]|"[^"]*"|\'[^\']*\')*>[\\s\\S]*?</style\\s*|/?[a-z](?:[^"\'>]|"[^"]*"|\'[^\']*\')*)>', 'gi');
-        return (data.replace(regex, ''));
-    }
+    ext.point('io.ox/core/stages').extend({
+        id: 'first',
+        index: 107,
+        run: function () {
+            if (_.url.hash('i') === 'guestReset') {
+                _.url.hash({ i: null, m: null, guardReset: 'true', app: 'io.ox/settings/main', folder: 'virtual/settings/oxguard' });
 
+            }
+        }
+    });
 });
