@@ -1,14 +1,25 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- * @author Greg Hill <greg.hill@open-xchange.com>
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
  */
+
 define('oxguard/settings/pane', [
     'io.ox/core/extensions',
     'io.ox/backbone/views/extensible',
@@ -35,15 +46,20 @@ define('oxguard/settings/pane', [
                     drawGuardSettings(node, baton);
                 });
             }
+            /**  Optional notification on save
+            settings.on('save', function () {
+                notifications.yell('success', gt('Saved'));
+            });
+            */
         }
     });
 
     var INDEX = 0;
 
     function drawGuardSettings(node, baton) {
+        node.empty();
         guardUtil.hasSetupDone()
         .done(function () {
-            node.empty();
             node.addClass('guard-settings');
             node.append(
                 new ExtensibleView({ point: 'oxguard/settings/detail/view', model: settings })
@@ -77,8 +93,10 @@ define('oxguard/settings/pane', [
         })
         .fail(function () {
             require(['io.ox/core/capabilities'], function (capabilities) {
-                if (capabilities.has('guard-mail') || capabilities.has('guard-drive')) {
+                if (capabilities.has('guard') && (capabilities.has('guard-mail') || capabilities.has('guard-drive'))) {
                     node.append(setupGuard(node, baton));
+                } else if (capabilities.has('smime')) {
+                    node.append(setupSmime(node, baton));
                 }
             });
             return;
@@ -91,7 +109,7 @@ define('oxguard/settings/pane', [
             index: INDEX += 100,
             render: function () {
                 this.$el.addClass('io-ox-guard-settings').append(
-                    util.header(gt('%s security settings', window.oxguarddata.productName))
+                    util.header(gt('%s security settings', ox.guard.getName()))
                 );
             }
         },
@@ -99,7 +117,25 @@ define('oxguard/settings/pane', [
             id: 'defaults',
             index: INDEX += 100,
             render: function () {
-                if (guardUtil.isGuest() || !guardUtil.hasGuardMailCapability()) return;   // Guests don't set defaults for sending
+                if (guardUtil.isGuest() || (!guardUtil.hasGuardMailCapability() && !guardUtil.hasSmime())) return;   // Guests don't set defaults for sending
+                var smime;
+                if (core.hasSmime() && guardUtil.hasGuardMailCapability()) {
+                    smime = util.checkbox('defaultSmime', gt('Default to using S/MIME for signing and encryption'), settings).css('display', settings.get('smime') ? 'block' : 'none').addClass('smimeDefaultOption');
+                    smime.on('change', function () {
+                        if (settings.get('defaultSmime')) {
+                            settings.set('defaultInline', false);
+                        }
+                    });
+                }
+                var pgpInline;
+                if (core.hasGuardMail()) {
+                    pgpInline = util.checkbox('defaultInline', gt('Default to using PGP inline for new mails'), settings).addClass('guardAdvanced').css('display', settings.get('advanced') ? 'block' : 'none');
+                    pgpInline.on('change', function () {
+                        if (settings.get('defaultInline')) {
+                            settings.set('defaultSmime', false);
+                        }
+                    });
+                }
                 this.$el.append(
                     $('<div class="guardDefaults">').append(
                         util.fieldset(
@@ -108,8 +144,9 @@ define('oxguard/settings/pane', [
                             util.checkbox('defaultEncrypted', gt('Default to send encrypted when composing email'), settings),
                             // default add signature
                             util.checkbox('defaultSign', gt('Default adding signature to outgoing mails'), settings),
+                            smime,
                             // inline
-                            util.checkbox('defaultInline', gt('Default to using PGP inline for new mails'), settings).addClass('guardAdvanced').css('display', settings.get('advanced') ? 'block' : 'none'),
+                            pgpInline,
                             util.compactSelect('defRemember', gt('Remember password default'), settings, this.getPasswordOptions())
                         )
                     )
@@ -128,10 +165,37 @@ define('oxguard/settings/pane', [
                 );
             }
         },
+        {
+            id: 'smime',
+            index: INDEX += 100,
+            render: function () {
+                if (core.hasSmime() && core.hasGuardMail() && !core.isGuest()) {
+                    var smime = util.checkbox('smime', gt('Enable S/MIME'), settings);
+                    smime.on('change', function () {
+                        if (settings.get('smime')) {
+                            $('.smimeDefaultOption').show();
+                        } else $('.smimeDefaultOption').hide();
+                        updateAdvanced();
+
+                    });
+                    this.$el.append(
+                        util.fieldset(
+                            gt('S/MIME'),
+                            // default to encrypt outgoing
+                            smime
+                        )
+                    );
+                }
+            }
+        },
         {
             id: 'Advanced',
             index: INDEX += 100,
             render: function () {
+                if (!core.hasGuard()) {  // If the user only has smime (no guard), go ahead and draw key buttons
+                    this.$el.append(drawAdvanced());
+                    return;
+                }
                 var advancedBox = util.checkbox('advanced', gt('Show advanced settings'), settings);
                 advancedBox.on('change', function () {
                     updateAdvanced();
@@ -165,9 +229,17 @@ define('oxguard/settings/pane', [
                 );
 
                 function openDialog() {
-                    ox.load(['oxguard/settings/views/changePasswordView']).done(function (view) {
+                    ox.load(['oxguard/settings/views/changePasswordView', 'oxguard/settings/views/selectTypeView']).done(function (view, selectType) {
                         var node = $('.guard-settings');
-                        view.open(node, baton);
+                        selectType.open({
+                            title: gt('Select type of keys to change'),
+                            pgpAction: function () {
+                                view.open(node, baton, 'pgp');
+                            },
+                            smimeAction: function () {
+                                view.open(node, baton, 'smime');
+                            }
+                        });
                     });
                 }
             }
@@ -178,7 +250,7 @@ define('oxguard/settings/pane', [
             render: function () {
 
                 // check enabled
-                if (!window.oxguarddata.recovery || window.oxguarddata.new) {  // If no recovery avail, then don't display reset button
+                if (!ox.guard.get('recoveryAvail') || ox.guard.get('new')) {  // If no recovery avail, then don't display reset button
                     return;
                 }
                 this.append(
@@ -188,8 +260,16 @@ define('oxguard/settings/pane', [
                 );
 
                 function openDialog() {
-                    ox.load(['oxguard/settings/views/resetPasswordView']).done(function (view) {
-                        view.open();
+                    ox.load(['oxguard/settings/views/resetPasswordView', 'oxguard/settings/views/selectTypeView']).done(function (view, selectType) {
+                        selectType.open({
+                            title: gt('Select type of keys to reset'),
+                            pgpAction: function () {
+                                view.open('pgp');
+                            },
+                            smimeAction: function () {
+                                view.open('smime');
+                            }
+                        });
                     });
                 }
             }
@@ -200,7 +280,7 @@ define('oxguard/settings/pane', [
             render: function () {
 
                 // check enabled
-                if (!window.oxguarddata.recovery || window.oxguarddata.new) {  // If no recovery avail, then don't display reset button
+                if (!ox.guard.get('recoveryAvail') || ox.guard.get('new')) {  // If no recovery avail, then don't display reset button
                     return;
                 }
                 this.append(
@@ -210,8 +290,16 @@ define('oxguard/settings/pane', [
                 );
 
                 function openDialog() {
-                    ox.load(['oxguard/settings/views/secondaryEmailView']).done(function (view) {
-                        view.open();
+                    ox.load(['oxguard/settings/views/secondaryEmailView', 'oxguard/settings/views/selectTypeView']).done(function (view, selectType) {
+                        selectType.open({
+                            title: gt('Select type of keys to change email reset'),
+                            pgpAction: function () {
+                                view.open('pgp');
+                            },
+                            smimeAction: function () {
+                                view.open('smime');
+                            }
+                        });
                     });
                 }
             }
@@ -221,7 +309,7 @@ define('oxguard/settings/pane', [
             index: 400,
             render: function (baton) {
                 // check enabled
-                if (!window.oxguarddata.recovery || window.oxguarddata.settings.noDeleteRecovery || window.oxguarddata.new || guardUtil.isGuest()) {  // If no recovery avail, then don't display reset button
+                if (!ox.guard.get('recoveryAvail') || ox.guard.get('new') || ox.guard.getSettings().noDeleteRecovery || guardUtil.isGuest()) {  // If no recovery avail, then don't display reset button
                     return;
                 }
                 var button = $('<button type="button" class="btn btn-default guardAdvanced" id="deleteRecovery">')
@@ -235,9 +323,17 @@ define('oxguard/settings/pane', [
 
                 this.append(button);
                 function openDialog() {
-                    ox.load(['oxguard/settings/views/deleteRecoveryView']).done(function (view) {
+                    ox.load(['oxguard/settings/views/deleteRecoveryView', 'oxguard/settings/views/selectTypeView']).done(function (view, selectType) {
                         var node = $('.guard-settings');
-                        view.open(node, baton);
+                        selectType.open({
+                            title: gt('Select type of keys to delete recovery'),
+                            pgpAction: function () {
+                                view.open(node, baton, 'pgp');
+                            },
+                            smimeAction: function () {
+                                view.open(node, baton, 'smime');
+                            }
+                        });
                     });
                 }
             }
@@ -248,6 +344,7 @@ define('oxguard/settings/pane', [
         var div = $('<div class="guardAdvanced" id="advancedDiv">');
         $('#deleteRecovery').show();
         var downloadPublic = $('<div>');
+
         var downloadPublicButton = $('<button type="button" class="btn btn-default" name="downloadPublic">')
         .text(gt('Download my public key'))
         .on('click', downloadPublicKey);
@@ -256,8 +353,12 @@ define('oxguard/settings/pane', [
         .text(gt('Your keys'))
         .on('click', openUserKeysDialog);
         function openUserKeysDialog() {
-            ox.load(['oxguard/settings/views/userKeysView']).done(function (view) {
-                view.open();
+            ox.load(['oxguard/settings/views/userKeysView', 'oxguard/settings/views/selectTypeView', 'oxguard/settings/smime/privateView']).done(function (view, selectType, smimeView) {
+                selectType.open({
+                    title: gt('Select type of keys to list'),
+                    pgpAction: view.open,
+                    smimeAction: smimeView.open
+                });
             });
         }
         var recipients = '';
@@ -273,8 +374,10 @@ define('oxguard/settings/pane', [
             }
         }
         function openDialog() {
-            ox.load(['oxguard/settings/views/publicKeysView']).done(function (view) {
-                view.open();
+            ox.load(['oxguard/settings/views/publicKeysView']).done(function (dialog) {
+                dialog.open({
+                    title: gt('Public keys of recipients')
+                });
             });
         }
         function openAutoCryptDialog() {
@@ -283,9 +386,19 @@ define('oxguard/settings/pane', [
             });
         }
         div.append(drawWipeOptions);
-        div.append(util.fieldset(
-            gt('Keys'), downloadPublic, userKeys, recipients, autoCrypt
-        ));
+        var pgp = core.hasGuardMail();
+        if (core.hasPGPandSmime()) {
+            div.append(util.fieldset(
+                gt('Keys'), userKeys));
+            div.append(util.fieldset(
+                gt('PGP'), downloadPublic, recipients, autoCrypt
+            ));
+        } else {
+            div.append(util.fieldset(
+                gt('Keys'), userKeys, pgp ? downloadPublic : '', pgp ? recipients : '', pgp ? autoCrypt : ''
+            ));
+        }
+
         div.append(drawVersion());
         return div;
     }
@@ -303,7 +416,7 @@ define('oxguard/settings/pane', [
     }
 
     function drawAutocrypt() {
-        if (!core.autoCryptEnabled()) return;
+        if (!core.autoCryptEnabled() || !core.hasGuardMail()) return;
         var div = $('<div class="autocryptSettings guardAdvanced">');
         var transfer = $('<button type="button" class="btn btn-default" name="transferKeys">')
         .text(gt('Autocrypt transfer keys'))
@@ -331,15 +444,16 @@ define('oxguard/settings/pane', [
     }
 
     function downloadPublicKey() {
-        require(['oxguard/settings/views/downloadPrivateView'], function (downloader) {
-            downloader.downloadPublic();
+        require(['oxguard/api/keys'], function (keysAPI) {
+            // current key
+            keysAPI.downloadAsFile({ keyType: 'public' });
         });
     }
 
     function drawVersion() {
         if (_.device('small')) return ('');
         var div = $('<div class="guardVersion">');
-        div.append(window.oxguarddata.version + '<br>build: ' + window.oxguarddata.server);
+        div.append(ox.guard.get('version') + '<br>build: ' + ox.guard.get('server'));
         return (div);
     }
 
@@ -363,20 +477,35 @@ define('oxguard/settings/pane', [
 
     function setupGuard(node, baton) {
         var div = $('<div>').addClass('io-ox-guard-settings');
-        var passheader = util.header(gt('%s security settings', window.oxguarddata.productName));
+        var passheader = util.header(gt('%s security settings', ox.guard.getName()));
         var instructions = $('<div>');
         //#. product name
-        instructions.append('<p>' + gt('In order to start with %s security, you must set up a password for your secured files.', window.oxguarddata.productName) + '</p>');
+        instructions.append('<p>' + gt('In order to start with %s security, you must set up a password for your secured files.', ox.guard.getName()) + '</p>');
         var startButton = $('<button type="button" class="btn btn-default guard-start-button">' + gt('Start') + '</button>');
         startButton.click(function () {
             require(['oxguard/core/createKeys'], function (keys) {
                 core.metrics('settings', 'create-keys');
                 keys.createKeysWizard()
-                .done(function (result) {
-                    if (result === 'OK') {
-                        ext.point('oxguard/settings/detail').invoke('draw', node, baton);
-                    }
-                    //$('.oxguard_settings').replaceWith(addSettings());
+                .done(function () {
+                    ext.point('oxguard/settings/detail').invoke('draw', node, baton);
+                });
+            });
+        });
+        return (div.append(passheader).append(instructions).append(startButton));
+    }
+
+    function setupSmime(node, baton) {
+        var div = $('<div>').addClass('io-ox-guard-settings');
+        var passheader = util.header(gt('%s security settings', ox.guard.getName()));
+        var instructions = $('<div>');
+        //#. product name
+        instructions.append('<p>' + gt('In order to start with %s security, you must upload an S/MIME key.', ox.guard.getName()) + '</p>');
+        var startButton = $('<button type="button" class="btn btn-default guard-start-button">' + gt('Start') + '</button>');
+        startButton.click(function () {
+            require(['oxguard/settings/smime/smimeUpload'], function (keys) {
+                keys.open()
+                .done(function () {
+                    ext.point('oxguard/settings/detail').invoke('draw', node, baton);
                 });
             });
         });
