@@ -1,3 +1,25 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 /**
  * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
  * LICENSE. This work is protected by copyright and/or other applicable
@@ -28,18 +50,19 @@ define('oxguard/settings/views/deleteRecoveryView', [
     var POINT = 'oxguard/settings/reset',
         INDEX = 0;
 
-    function open(node, baton) {
-        return openModalDialog(node, baton);
+    function open(node, baton, type) {
+        return openModalDialog(node, baton, type);
     }
 
-    function openModalDialog(node, baton) {
+    function openModalDialog(node, baton, type) {
 
         return new ModalView({
             async: true,
             focus: 'input[name="active"]',
             point: POINT,
             title: gt('Delete Recovery'),
-            width: 640
+            width: 640,
+            model: new Backbone.Model({ type: type })
         })
         .inject({
         })
@@ -48,10 +71,9 @@ define('oxguard/settings/views/deleteRecoveryView', [
         .addCancelButton()
         .addButton({ label: gt('Delete'), action: 'delete' })
         .on('delete', function () {
-            this.close();
-            performDelete().done(function () {
+            performDelete(this.model.get('type')).done(function () {
                 ext.point('oxguard/settings/detail').invoke('draw', node, baton);  // redraw settings
-            }).fail(this.idle).fail(yell);
+            }).done(this.close).fail(this.idle).fail(yell);
         })
         .open();
     }
@@ -69,7 +91,7 @@ define('oxguard/settings/views/deleteRecoveryView', [
         }
     );
 
-    function performDelete() {
+    function performDelete(type) {
         var def = $.Deferred();
         core.getPassword(gt('Please verify your password before deleting the recovery.'))
         .done(function (e) {
@@ -79,10 +101,17 @@ define('oxguard/settings/views/deleteRecoveryView', [
                 password: e.password
             };
             core.metrics('settings', 'delete-recovery');
-            og_http.post(ox.apiRoot + '/oxguard/login?action=deleterecovery', '', data)
-            .done(function () {
+            og_http.post(ox.apiRoot + '/oxguard/login?action=deleterecovery&type=' + type, '', data)
+            .done(function (e) {
+                if (e && e.error) {
+                    if (e.error === 'none') {
+                        yell('error', gt('Unable to delete recovery.  Possibly wrong password for one or more keys, or no keys found'));
+                        def.reject();
+                        return;
+                    }
+                }
                 yell('success', gt('Recovery deleted'));
-                window.oxguarddata.recovery = false;
+                ox.guard.set('recoveryAvail', false);
                 def.resolve();
             })
             .fail(function (e) {
