@@ -1,3 +1,25 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 /**
  * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
  * LICENSE. This work is protected by copyright and/or other applicable
@@ -28,8 +50,10 @@ define('oxguard/settings/views/secondaryEmailView', [
     var POINT = 'oxguard/settings/secondary',
         INDEX = 0;
 
-    function open() {
-        return getSecondary().then(openModalDialog, fail);
+    function open(type) {
+        return getSecondary(type).then(function (secondary) {
+            openModalDialog(secondary, type);
+        }, fail);
     }
 
     function fail(e) {
@@ -40,21 +64,22 @@ define('oxguard/settings/views/secondaryEmailView', [
         throw e;
     }
 
-    function openModalDialog(secondary) {
+    function openModalDialog(secondary, type) {
 
         return new ModalView({
             async: true,
             focus: 'input[name="active"]',
             point: POINT,
             title: gt('Secondary Email Address'),
-            width: 640
+            width: 640,
+            model: new Backbone.Model({ type: type })
         })
         .inject({
             doChange: function () {
                 var email = $('input[name="newemail"]');
                 var verify = $('input[name="newemailverify"]');
                 var password = $('#ogpass');
-                return changeSecondary(email, verify, password);
+                return changeSecondary(email, verify, password, this.model.get('type'));
             },
             updateEmail: function () {
                 this.$body.find('#secondaryEmail').text(secondary);
@@ -69,7 +94,7 @@ define('oxguard/settings/views/secondaryEmailView', [
             this.doChange().done(this.close).fail(this.idle).fail(yell);
         })
         .on('open', function () {
-            this.updateEmail();
+            this.updateEmail(this.model.get('type'));
         })
         .open();
     }
@@ -88,7 +113,7 @@ define('oxguard/settings/views/secondaryEmailView', [
     );
 
     function createSecondaryChange() {
-        if (window.oxguarddata.settings.noRecovery === true || window.oxguarddata.recovery === false) return;  // Don't display secondary email if no recovery is set
+        if (ox.guard.getSettings().noRecovery === true || ox.guard.get('recoveryAvail') === false) return;  // Don't display secondary email if no recovery is set
         var current = $('<span>').append(gt('Current email address:'));
         var currentEmail = $('<span id="secondaryEmail" style="padding-left:20px;">');
         var emailheader =
@@ -102,7 +127,7 @@ define('oxguard/settings/views/secondaryEmailView', [
         var noSaveWorkAround = $('<input style="display:none" type="text" name="dontremember"/><input style="display:none" type="password" name="dontrememberpass"/>');
         var emailAddr = $('<input name="newemail" id="newemail" class="form-control"/>');
         var verifyPass = $('<input name="newemailverify" id="newemailverify" class="form-control">');
-        var currentPrompt = $('<label for="ogpass">').append(gt('Enter current %s security password', window.oxguarddata.productName));
+        var currentPrompt = $('<label for="ogpass">').append(gt('Enter current %s security password', ox.guard.getName()));
         var currentInput = new PasswordView.view({ 'id': 'ogpass', 'class': 'password_prompt' }).getProtected();
         var newPrompt = $('<label for="newemail">').append(gt('Enter new secondary email address'));
         var verifyPrompt = $('<label for="newemailverify">').append(gt('Verify email address'));
@@ -127,9 +152,9 @@ define('oxguard/settings/views/secondaryEmailView', [
         return (emailheader.append(emailTable).append(errorDiv));
     }
 
-    function getSecondary() {
+    function getSecondary(type) {
         var def = $.Deferred();
-        og_http.get(ox.apiRoot + '/oxguard/login?action=secondary', '&userid=' + ox.user_id + '&cid=' + ox.context_id)
+        og_http.get(ox.apiRoot + '/oxguard/login?action=secondary', '&userid=' + ox.user_id + '&cid=' + ox.context_id + '&type=' + type)
         .done(function (d) {
             d = d.trim();
             if (d.length < 2) {
@@ -152,7 +177,7 @@ define('oxguard/settings/views/secondaryEmailView', [
         return def;
     }
 
-    function changeSecondary(emailInput, verifyEmailInput, passwordInput) {
+    function changeSecondary(emailInput, verifyEmailInput, passwordInput, type) {
         var def = $.Deferred();
         var email = emailInput.val();
         var verifyEmail = verifyEmailInput.val();
@@ -173,8 +198,13 @@ define('oxguard/settings/views/secondaryEmailView', [
             password: passwordInput.val()
         };
         core.metrics('settings', 'change-secondary-email');
-        og_http.post(ox.apiRoot + '/oxguard/login?action=changesecondary', '', data)
-            .done(function () {
+        og_http.post(ox.apiRoot + '/oxguard/login?action=changesecondary', '&type=' + type, data)
+            .done(function (data) {
+                if (data.error) {
+                    showError(data.error);
+                    def.reject();
+                    return;
+                }
                 showOK(gt('Successfully changed email address'));
                 $('input[name="ogpass"]').val('');
                 $('input[name="newemail"]').val('');
