@@ -1,3 +1,25 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 /**
  * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
  * LICENSE. This work is protected by copyright and/or other applicable
@@ -31,18 +53,19 @@ define('oxguard/settings/views/uploadPrivateView', [
 
     var dialog;
 
-    function open() {
-        dialog = openModalDialog();
+    function open(smime) {
+        dialog = openModalDialog(smime);
         return dialog;
     }
 
-    function openModalDialog() {
+    function openModalDialog(smime) {
 
         return new ModalView({
             async: true,
             point: POINT,
             title: gt('Adding Keys'),
-            width: 640
+            width: 640,
+            model: new Backbone.Model({ smime: smime })
         })
         .inject({
         })
@@ -56,12 +79,18 @@ define('oxguard/settings/views/uploadPrivateView', [
         {
             index: INDEX += 100,
             id: 'uploadPrivate',
-            render: function () {
+            render: function (baton) {
                 var label = $('<label for="uploadPrivateButton">').append(gt('If you already have a private key, you can upload it here.'))
                     .append('<br>');
                 var button = $('<button type="button" class="upload-view btn btn-primary" id="uploadPrivateButton">')
                     .text(gt('Upload private key'))
                     .on('click', function () {
+                        if (baton.model.get('smime')) {
+                            ox.load(['oxguard/settings/smime/smimeUpload']).done(function (view) {
+                                view.open();
+                            });
+                            return;
+                        }
                         openUploadPrivateDialog(true);
                     });
                 this.$body.append(
@@ -72,9 +101,10 @@ define('oxguard/settings/views/uploadPrivateView', [
         {
             index: INDEX += 100,
             id: 'uploadPublic',
-            render: function () {
+            render: function (baton) {
+                if (baton.model.get('smime')) return;
                 var label = $('<label for="uploadPublicButton">').append(
-                    gt('If you would like to upload a public key only, then do so here.  This will allow you to encrypt files and receive encrypted emails using %s, but you will need to use the private key with another program to decode the items.', window.oxguarddata.productName))
+                    gt('If you would like to upload a public key only, then do so here.  This will allow you to encrypt files and receive encrypted emails using %s, but you will need to use the private key with another program to decode the items.', ox.guard.getName()))
                     .append('<br>');
                 var button = $('<button type="button" class="upload-view btn btn-primary" id="uploadPublicButton">')
                     .text(gt('Upload public key only'))
@@ -89,7 +119,8 @@ define('oxguard/settings/views/uploadPrivateView', [
         {
             index: INDEX += 100,
             id: 'createNewKeys',
-            render: function () {
+            render: function (baton) {
+                if (baton.model.get('smime')) return;
                 var label = $('<label for="createNewButton">').append(gt('Finally, you can have a new PGP Key Pair created for your account.'))
                     .append('<br>');
                 var dialog = this;
@@ -127,7 +158,7 @@ define('oxguard/settings/views/uploadPrivateView', [
                         uploader.uploadPrivate(files)
                         .done(function () {
                             dialog.close();
-                            window.oxguarddata.passcode = null;
+                            ox.guard.clearAuth();
                             $('#refreshuserkeys').click();
                         })
                         .fail(function () {
