@@ -1,12 +1,23 @@
-/**
- * All content on this website (including text, images, source
- * code and any other original works), unless otherwise noted,
- * is licensed under a Creative Commons License.
+/*
  *
- * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
- * Copyright (C) 2016-2020 OX Software GmbH
- * Author Greg Hill <greg.hill@open-xchange.com>
  */
 
 define('oxguard/tour/main', [
@@ -46,12 +57,20 @@ define('oxguard/tour/main', [
         });
     }
 
+    var helpView = new HelpView({
+        base: 'help',
+        modal: true,
+        content: gt.format(gt.pgettext('tour', 'Learn more about %s'), ox.guard.getName())
+    });
+
+    var helpViewLink = helpView.render().$el;
+
     Tour.registry.add({
         id: 'default/oxguard',
         priority: 1
     }, function () {
         if (!util.isGuardConfigured()) {
-            Tour.registry.run('default/oxguard/createKeys');
+            keys.createKeysWizard();
             return;
         }
 
@@ -61,10 +80,10 @@ define('oxguard/tour/main', [
         var driveText = '';
         var resetText = '';
         // Select text depending on if recovery is available
-        if (window.oxguarddata.recoveryAvail) {
-            resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account. But you can always change your encryption password, or request a temporary password if you forget it.'), window.oxguarddata.productName);
+        if (ox.guard.get('recoveryAvail')) {
+            resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account. But you can always change your encryption password, or request a temporary password if you forget it.'), ox.guard.getName());
         } else {
-            resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account.  You can change your encryption password here.'), window.oxguarddata.productName);
+            resetText = gt.format(gt.pgettext('tour', 'You already set up your %s account.  You can change your encryption password here.'), ox.guard.getName());
         }
         // minimze all open windows
         ox.ui.apps.models.forEach(function (app) {
@@ -74,7 +93,7 @@ define('oxguard/tour/main', [
         });
         tour.toggleBackdrop(true);
         tour.step({ labelNext: gt('Next') })
-            .title(gt.format(gt.pgettext('tour', 'The %s module'), window.oxguarddata.productName))
+            .title(gt.format(gt.pgettext('tour', 'The %s module'), ox.guard.getName()))
             .content(gt.pgettext('tour', 'Security and privacy matters to everyone. That\'s why you can now send and receive encrypted emails by simply clicking on the lock icon.'))
             .waitFor('.og-ready', 10)
             .on('wait', function () {
@@ -112,12 +131,12 @@ define('oxguard/tour/main', [
         tour
         .step()
             //#. %s product Name
-            .title(gt.format(gt.pgettext('tour', '%s Security Settings'), window.oxguarddata.productName))
+            .title(gt.format(gt.pgettext('tour', '%s Security Settings'), ox.guard.getName()))
             .content(resetText)
             .on('wait', function () {
                 composeApp.getWindow().floating.minimize();  // Minimize the floating window
                 ox.launch('io.ox/settings/main', { id: 'oxguard' }).then(function () {
-                    this.setSettingsPane({ id: 'oxguard' });
+                    this.setSettingsPane({ id: 'oxguard', refresh: true });
                 });
             })
             .waitFor('#passwordDiv')
@@ -125,7 +144,7 @@ define('oxguard/tour/main', [
             .spotlight('#passwordDiv', { 'padding': 10 })
             .end()
         .step()
-            .title((settings.get('advanced') ? gt.pgettext('tour', 'PGP Encryption Settings') : gt.pgettext('tour', 'Security Settings')))
+            .title((settings.get('advanced') ? gt.pgettext('tour', 'Encryption Settings') : gt.pgettext('tour', 'Security Settings')))
             .content((settings.get('advanced') ?
                 gt.pgettext('tour', 'From here you can update your encryption settings. For example you can choose to send encrypted emails by default.') :
                 gt.pgettext('tour', 'From here, you can update your security settings.  For example, you can choose to send secure emails by default.')))
@@ -140,10 +159,10 @@ define('oxguard/tour/main', [
             .spotlight('.guardDefaults', { 'padding': 10 })
             .hotspot('.guardDefaults [name="defaultSign"]', { 'top': 7, 'left': 7 })
             .end();
-        if (settings.get('advanced')) {
+        if (settings.get('advanced') && core.hasGuardMail()) {
             tour.step()
             .title(gt.pgettext('tour', 'Alternative: PGP Inline'))
-            .content(gt.format(gt.pgettext('tour', 'By default %s sends encrypted emails using PGP/Mime format. To communicate with some systems you may need to use PGP Inline.'), window.oxguarddata.productName))
+            .content(gt.format(gt.pgettext('tour', 'By default %s sends encrypted emails using PGP/Mime format. To communicate with some systems you may need to use PGP Inline.'), ox.guard.getName()))
             .waitFor('.guardDefaults')
             .spotlight('.guardDefaults', { 'padding': 10 })
             .hotspot('.guardDefaults [name="defaultInline"]', { 'top': 7, 'left': 7 })
@@ -171,7 +190,7 @@ define('oxguard/tour/main', [
             .on('show', function () {
             })
             .end();
-        } else {
+        } else if (core.hasGuard()) {
             tour
             .step()
             .title(gt.pgettext('tour', 'Advanced User Settings'))
@@ -267,11 +286,14 @@ define('oxguard/tour/main', [
                 $('<hr>'),
                 $('<p>').append($('<a href="#">').click(setEncryptDefault).text(gt.pgettext('tour', 'Activate encryption for all new emails'))),
                 $('<p>').append($('<a href="#">').click(openSettings).text(gt.pgettext('tour', 'Review your encryption settings'))),
-                $('<p class="help">').append(new HelpView({
-                    base: 'help',
-                    content: gt.pgettext('tour', 'Learn more')
-                }).render().$el)
+                $('<p>').append(helpViewLink)
             ))
+            .on('ready', function () {
+                helpView.$el.on('click', function () {
+                    def.resolve();
+                    tour.close();
+                });
+            })
             .end()
         .start();
         return def;
@@ -291,7 +313,7 @@ define('oxguard/tour/main', [
         }
 
         var tour = new Tour(),
-            model = new keys.CreateKeysViewModel({
+            model = new keys.CreateKeysModel({
                 initialSetup: true
             }),
             view = new keys.CreateKeysView({
@@ -314,18 +336,18 @@ define('oxguard/tour/main', [
         //Guard is not configured, yet.
         if (!configured) {
             tour.step({ labelNext: gt('Start Setup') })
-            .title(gt.format(gt.pgettext('tour', 'Setup %s'), window.oxguarddata.productName))
+            .title(gt.format(gt.pgettext('tour', 'Setup %s'), ox.guard.getName()))
             .content($('<div>').append(
                 //#. %s product name
                 $('<p>').text(gt.format(gt.pgettext('tour', 'Welcome to %1$s. You will now be taken on a tour, showing you how to use %1$s.'),
-                    window.oxguarddata.productName)))
+                    ox.guard.getName())))
                 .append($('<p>').text(gt.format(gt.pgettext('tour', 'Firstly however, you’ll need to setup %1$s by choosing a password which will be used to encrypt or decrypt items such as email or files.'
-                ), window.oxguarddata.productName)))
+                ), ox.guard.getName())))
             )
             .end()
         .step()
             //#. %s product name
-            .title(gt('Choose %s Password', window.oxguarddata.productName))
+            .title(gt('Choose %s Password', ox.guard.getName()))
             .content(view.render().$el)
             .beforeShow(function () {
                 var self = this;
@@ -361,20 +383,17 @@ define('oxguard/tour/main', [
         tour
         .step({ labelDone: gt('Close') })
             //#. %s product Name
-            .title(gt.format(gt.pgettext('tour', '%s set up completed'), window.oxguarddata.productName))
+            .title(gt.format(gt.pgettext('tour', '%s set up completed'), ox.guard.getName()))
             .content($('<div>').append(
-                $('<p>').text(gt.format(gt.pgettext('tour', 'Congratulations, you have successfully setup %s'), window.oxguarddata.productName)),
-                $('<p>').text(gt.format(gt.pgettext('tour', 'Now you can learn more about how to use %s by following the links below:'), window.oxguarddata.productName)),
+                $('<p>').text(gt.format(gt.pgettext('tour', 'Congratulations, you have successfully setup %s'), ox.guard.getName())),
+                $('<p>').text(gt.format(gt.pgettext('tour', 'Now you can learn more about how to use %s by following the links below:'), ox.guard.getName())),
                 $('<p>').append($('<a id="startTourLink" href="#">').click(function () {
                     model.set('pending', true);
                     $('.wizard-step .btn-primary').click();
                     Tour.registry.get('default/oxguard').get('run')().then(def.resolve, def.resolve);
                     //#. %s product name
-                }).text(gt('Guided tour for %s', window.oxguarddata.productName))),
-                $('<p>').append(new HelpView({
-                    base: 'help',
-                    content: gt.format(gt.pgettext('tour', 'Learn more about %s'), window.oxguarddata.productName)
-                }).render().$el)
+                }).text(gt('Guided tour for %s', ox.guard.getName()))),
+                $('<p>').append(helpViewLink)
             ))
             .mandatory()
             .beforeShow(function () {
@@ -384,6 +403,10 @@ define('oxguard/tour/main', [
             .on('ready', function () {
                 //HACK: no way to pause the wizard until some event
                 $('body').removeClass('og-ready');
+                helpView.$el.on('click', function () {
+                    def.resolve();
+                    tour.close();
+                });
             })
             .waitFor('.og-ready', 30)
             .end()
