@@ -1,3 +1,25 @@
+/*
+ *
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
+ *
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
+ *
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
+ *
+ */
+
 /* eslint-env node, es6  */
 var defaultContext;
 
@@ -10,6 +32,19 @@ require('dotenv').config();
     process.exit();
 });
 
+//  Parse the domain from launch URL to use in share configuration
+function getShareDomain() {
+    var url = process.env.LAUNCH_URL;
+    if (url.indexOf('//') > 0) {
+        url = url.substring(url.indexOf('//') + 2);
+    }
+    if (url.indexOf('/') > 0) {
+        url = url.substring(0, url.indexOf('/'));
+    }
+    return url;
+}
+
+
 module.exports.config = {
     tests: './e2e/tests/**/*_test.js',
     timeout: 10000,
@@ -41,6 +76,8 @@ module.exports.config = {
             filestoreId: process.env.FILESTORE_ID || 6,
             smtpServer: process.env.SMTP_SERVER || 'localhost',
             imapServer: process.env.IMAP_SERVER || 'localhost',
+            shareDomain: process.env.SHARE_DOMAIN || getShareDomain(),
+            skipTests: process.env.SKIP_TESTS,
             newContext: parseInt(process.env.CONTEXT_ID, 10) + 1,
             admin: {
                 login: process.env.PROVISIONING_USER || 'oxadminmaster',
