@@ -27,19 +27,28 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        this.waitForInvisible('.window-blocker.io-ox-busy');
        this.waitForVisible('.io-ox-mail-compose textarea.plain-text,.io-ox-mail-compose .contenteditable-editor');
 
+       if (options.smime) {
+          this.click(optionsDropdown);
+          this.waitForText('Use S/MIME', 10, '.dropdown.open .dropdown-menu');
+          this.click('Use S/MIME', '.dropdown.open .dropdown-menu');
+         }
+
        // Mark as secure unless specified as non-encrypted
        if (!options.unencrypted) {
           this.seeElement('.io-ox-mail-compose-window .toggle-encryption');
           this.click('.io-ox-mail-compose-window .toggle-encryption');
-          this.waitForVisible('#ogPassword');
-          this.fillField('#ogPassword', userdata.password);
-          this.click('.btn[data-action="ok"]');
+          if (!options.smime_only && !options.smime) {  // When using smime, no password prompt
+               this.waitForVisible('#ogPassword');
+               this.fillField('#ogPassword', userdata.password);
+               this.click('.btn[data-action="ok"]');
+          }
           this.waitForVisible('.fa.fa-2x.encrypted');
        }
 
        if (options.attachKey) {
           this.click(optionsDropdown);
           this.waitForText('Attach my public key', 10, '.dropdown.open .dropdown-menu');
+          this.wait(1);
           this.click('Attach my public key', '.dropdown.open .dropdown-menu');
           this.waitForElement('.file[title="public.asc"]');
        }
@@ -59,8 +68,9 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        if (options.inline) {
         this.wait(1);
         this.click('.security-options a');
-        this.waitForVisible('.dropdown.open a[data-name="PGPFormat"]');
-        this.click('.dropdown.open a[data-value="inline"]');
+        this.waitForVisible('.dropdown.open a[data-name="pgpInline"]');
+        this.wait(1);
+        this.click('Inline');
         this.waitForVisible('.btn[data-action="okx"]');
         this.click('.btn[data-action="okx"]');
         this.waitForInvisible('.modal-backdrop');
@@ -89,14 +99,18 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        if (!options.unencrypted) {
             this.waitForVisible('i.fa.fa-key.oxguard_token.key_tooltip.trusted_key');
        }
-       this.click('Send');
 
-       if (options.sign) {
-           this.waitForVisible('#ogPassword');
-           this.fillField('#ogPassword', userdata.password);
-           this.click('.btn[data-action="ok"]');
+       if (!options.dontsend) {
+          this.click('Send');
+
+          if (options.sign) {
+              this.waitForVisible('#ogPassword');
+              this.fillField('#ogPassword', userdata.password);
+              this.click('.btn[data-action="ok"]');
+          }
+          this.waitForVisible('.io-ox-mail-window .leftside');
+          I.waitForInvisible('.mail-progress', attachment ? 60 : 10);
        }
-       this.waitForVisible('.io-ox-mail-window .leftside');
-       I.waitForInvisible('.mail-progress', attachment ? 60 : 10);
+
 
 };
