@@ -29,10 +29,14 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        if (!options.unencrypted) {
         this.click('Security');
         this.waitForVisible('.dropdown-menu a[data-name="encrypt"]');
-        this.click('Encrypt');
-        this.waitForVisible('#ogPassword');
-        this.fillField('#ogPassword', userdata.password);
-        this.click('.btn[data-action="ok"]');
+        if (options.smime) {
+             this.click('Secure');
+        } else {
+          this.click('Encrypt');
+          this.waitForVisible('#ogPassword');
+          this.fillField('#ogPassword', userdata.password);
+          this.click('.btn[data-action="ok"]');
+        }
        }
 
        if (options.attachKey) {
@@ -51,8 +55,8 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        if (options.inline) {
         this.wait(1);
         this.click('Security');
-        this.waitForVisible('.dropdown-menu a[data-name="PGPFormat"]');
-        this.click('.dropdown-menu a[data-value="inline"]');
+        this.waitForVisible('.dropdown-menu a[data-name="pgpInline"]');
+        this.click('.dropdown-menu a[data-value="true"]');
         this.waitForVisible('.btn[data-action="okx"]');
         this.click('.btn[data-action="okx"]');
         this.waitForInvisible('.modal-backdrop');
@@ -81,7 +85,12 @@ module.exports  = function (userdata, subject, data, attachment, options) {
        if (!options.unencrypted) {
             this.waitForVisible('i.fa.fa-key.oxguard_token.key_tooltip.trusted_key');
             // Send
-            this.click('Send Encrypted');
+            if (options.smime) {
+                 this.click('Send Secure');
+            } else {
+                 this.click('Send Encrypted');
+            }
+            
        } else {
            this.click('Send');
        }
