@@ -16,7 +16,7 @@
  */
 
 
-module.exports  = function (userIndex) {
+module.exports  = function () {
     this.waitForVisible('.io-ox-mail-window .window-body .classic-toolbar');
     // Mark empty inbox (needed for temporary password prompt with correct email)
     this.selectFolder('Inbox');
