@@ -121,7 +121,7 @@ Scenario ('I remove decrypted emails when switching apps', async function (I, us
     I.waitForElement('.og_password input.form-control.password_prompt');
 });
 
-Scenario ('I remove decrypted emails but not within threads', async function (I, users) {
+Scenario.skip ('I remove decrypted emails but not within threads', async function (I, users) {
 
     const o = {
         user: users[0]
