@@ -49,25 +49,64 @@ Scenario('View details of your keys', async function (I, users) {
 
     // Check key details
     I.click('.userpgpdetail');
-    I.waitForVisible('.keystart');
+    I.waitForVisible('.details dl');
     let keyDetail = await I.grabTextFrom('#privKeyDetail .modal-body');
     assert.include(keyDetail, 'Fingerprint', 'Key Detail includes fingerprint');
 
     // Check able to check signatures
     I.click('.btn[data-action="signatures"]');
-    I.wait(1);
+    I.waitForVisible('#pkeyDetail');
     I.see('Public Keys Detail', '#pkeyDetail .modal-title');
     I.seeNumberOfVisibleElements('tr', 2);
     I.see('Positive', '[title="Positive certification of a User ID"]');
 
     // Close all
-    I.click('#pkeyDetail [data-action="done"]');
-    I.click('#privKeyDetail [data-action="done"]');
-    I.click('.btn[data-action="done"]');
+    I.click('#pkeyDetail [data-action="cancel"]');
+    I.click('#privKeyDetail [data-action="cancel"]');
+    I.click('.btn[data-action="cancel"]');
     I.logout();
 
 });
 
+Scenario('PGP change password', async function (I, users) {
+
+    const o = {
+        user: users[0]
+    };
+    const userdata = o.user.userdata;
+
+    // Log in to settings
+    I.login('app=io.ox/mail', o);
+    await I.verifyUserSetup(userdata);
+
+    // Next, log in to settings
+    await I.goToSettings();
+
+    I.see('Change password');
+
+    I.click('Change password');
+
+    I.waitForVisible('#oldpass');
+
+    I.fillField('#oldpass', userdata.password);
+
+    I.fillField('#newpass1', userdata.password + '2');
+
+    I.fillField('#newpass2', userdata.password);
+
+    I.see('Passwords not equal');
+
+    I.pressKey('2');
+
+    I.click('Change');
+
+    I.waitForVisible('.io-ox-alert');
+
+    I.see('Password changed', '.io-ox-alert');
+
+
+});
+
 Scenario('Upload public keys and verify available', async function (I, users) {
 
     const o = {
@@ -118,11 +157,11 @@ Scenario('Upload public keys and verify available', async function (I, users) {
     I.waitForVisible('.signatureTable');
     I.seeNumberOfVisibleElements('tr', 2);
     I.see('Positive', '.signatureTable');
-    I.click('.modal[data-point="oxguard/pgp/signatureview"] [data-action="done"]');
+    I.click('.modal[data-point="oxguard/pgp/signatureview"] [data-action="cancel"]');
     I.wait(1);
 
-    I.click('#pkeyDetail [data-action="done"]');
-    I.click('#pkeyList [data-action="done"]');
+    I.click('#pkeyDetail [data-action="cancel"]');
+    I.click('#pkeyList [data-action="cancel"]');
 
     // Start a mail to see if key properly loaded
     I.openApp('Mail');
@@ -166,7 +205,7 @@ Scenario('Private Key Download and Upload', async function (I, users) {
     I.click('.btn[name="yourKeys"]');
     I.waitForVisible('.delPriv');
     // Get the keyId from table and download
-    let keyId = await I.grabAttributeFrom('.delPriv', 'value');
+    let keyId = await I.grabAttributeFrom('#userkeytable tr', 'data-id')
     let downloadedKey = await I.downloadPrivateKey(keyId, userdata);
 
     // OK, delete the key
@@ -203,17 +242,17 @@ Scenario('Private Key Download and Upload', async function (I, users) {
     }, downloadedKey, userdata);
 
     // Cancel dialog since uploaded already
-    I.click('.btn[data-action="cancel"]');
+    I.click('Cancel');
 
     // Confirm key is now there and same
     I.click('#refreshuserkeys');
     I.wait(1);
     I.waitForVisible('.delPriv');
-    let checkKeyId = await I.grabAttributeFrom('.delPriv', 'value');
+    let checkKeyId = await I.grabAttributeFrom('#userkeytable tr', 'data-id')
     assert.equal(checkKeyId[0], keyId[0], 'Key Ids should match');
 
     // Cleanup
-    I.click('.btn[data-action="done"]');
+    I.click('.btn[data-action="cancel"]');
     I.logout();
 
 });
@@ -252,13 +291,69 @@ Scenario('Revoke Private Key', async function (I, users) {
 
     // Check detail
     I.click('.userpgpdetail');
-    I.waitForVisible('#privKeyDetail .modal-title');
-    let keyDetail = await I.grabTextFrom('#privKeyDetail .modal-body');
-    assert.include(keyDetail, 'Revoked', 'Key Detail shows revoked');
+    I.waitForVisible('.info-line.stripes-red');
+    I.see('Revoked', '.info-line');
 
     // Cleanup
-    I.click('#privKeyDetail [data-action="done"]');
-    I.click('.btn[data-action="done"]');
+    I.click('#privKeyDetail [data-action="cancel"]');
+    I.click('.btn[data-action="cancel"]');
     I.logout();
 
 });
+
+// Confirm element is checked or not in keytable row
+function confirm(checked, location) {
+    const { I } = inject();
+    within(locate('.keytable tr').at(location), () => {
+        if (checked) {
+            I.seeElement('.fa-check');
+        } else {
+            I.seeElement('input.makecurrent');
+        }
+    })
+}
+
+Scenario('Select current key', async function (I, users) {
+
+    const o = {
+        user: users[0]
+    };
+    const userdata = o.user.userdata;
+
+    await I.setupUser(o, true);  // need advanced settings
+
+    I.login('app=io.ox/mail', o);
+    await I.verifyUserSetup(userdata);
+    await I.verifyUserSetup(userdata, true);  // Additional key
+
+    // Next, log in to settings
+    await I.goToSettings();
+
+    // Open keys
+    I.waitForVisible('.btn[name="yourKeys"]');
+    I.click('.btn[name="yourKeys"]');
+    I.waitForVisible('.keytable .fa-check');
+    // Confirm 5 rows (2 keys plus divider)
+    I.seeNumberOfVisibleElements('.keytable tr', 5);
+    // First row has check, fourth row input
+    confirm(true, 1);
+    confirm(false, 4);
+    // Make current
+    I.click('input.makecurrent', locate('.keytable tr').at(4));
+    I.wait(1);
+    // Confirm flip of input/check
+    confirm(false, 1);
+    confirm(true, 4);
+    // Close and re-open to confirm persist
+    I.click('Close');
+    I.waitForInvisible('.keytable');
+    I.waitForVisible('.btn[name="yourKeys"]');
+    I.click('.btn[name="yourKeys"]');
+    I.waitForVisible('.keytable .fa-check');
+    I.seeNumberOfVisibleElements('.keytable tr', 5);
+    // Still flipped
+    confirm(false, 1);
+    confirm(true, 4);
+    
+
+});
