@@ -16,27 +16,6 @@ define('oxguard/crypto/encr', ['oxguard/crypto/jsencrypt'],
         }
     }
 
-    function loadPublicKey(data) {
-        try {
-            var encrypt = new JS.JSEncrypt();
-            encrypt.setPublicKey(data);
-            window.oxguarddata.publicKey = encrypt.getPublicKey();
-            window.oxguarddata.pubkey64 = data;
-            if (encrypt.getPublicKey === null) return false;
-            if (encrypt.getPublicKey().indexOf('PUBLIC') > 0) {// verify key loaded
-                return true;
-            } else {
-                alert(gt('Unable to load'));
-                return false;
-            }
-        } catch (e) {
-            console.log(e);
-            alert(gt('Unable to load'));
-            return false;
-        }
-
-    }
-
     function getEncrypted(pubKey, data) {
         try {
             if (pubKey.key === null) return(null);
@@ -55,8 +34,8 @@ define('oxguard/crypto/encr', ['oxguard/crypto/jsencrypt'],
     }
 
     function cryptPass (password) {
-        if (window.oxguarddata.pubKey === undefined) return(null);
-        return (getEncrypted (window.oxguarddata.pubKey, password));
+        if (ox.guard.get('pubKey') === undefined) return(null);
+        return (getEncrypted (ox.guard.get('pubKey'), password));
     }
 
 /*
@@ -112,9 +91,6 @@ define('oxguard/crypto/encr', ['oxguard/crypto/jsencrypt'],
 
     return {
         test : test,
-  //      createForm : createForm,
-  //      decodeKey : decodeKey,
-        loadPublicKey : loadPublicKey,
         getEncrypted : getEncrypted,
         cryptPass : cryptPass
     };
